@@ -27,12 +27,20 @@ Functions
 typedef struct BackupFile
 {
     const String *pgFile;                                           // Pg file to backup
+    bool pgFileDelta;                                               // Checksum pg file before copying
     bool pgFileIgnoreMissing;                                       // Ignore missing pg file
     uint64_t pgFileSize;                                            // Expected pg file size
     bool pgFileCopyExactSize;                                       // Copy only pg expected size
-    const String *pgFileChecksum;                                   // Expected pg file checksum
+    const Buffer *pgFileChecksum;                                   // Expected pg file checksum
     bool pgFileChecksumPage;                                        // Validate page checksums?
+    uint64_t blockIncrSize;                                         // Perform block incremental on this file?
+    const String *blockIncrMapPriorFile;                            // File containing prior block incremental map (NULL if none)
+    uint64_t blockIncrMapPriorOffset;                               // Offset of prior block incremental map
+    uint64_t blockIncrMapPriorSize;                                 // Size of prior block incremental map
     const String *manifestFile;                                     // Repo file
+    const Buffer *repoFileChecksum;                                 // Expected repo file checksum
+    uint64_t repoFileSize;                                          // Expected repo file size
+    bool manifestFileResume;                                        // Checksum repo file before copying
     bool manifestFileHasReference;                                  // Reference to prior backup, if any
 } BackupFile;
 
@@ -41,14 +49,16 @@ typedef struct BackupFileResult
     const String *manifestFile;                                     // Manifest file
     BackupCopyResult backupCopyResult;
     uint64_t copySize;
-    String *copyChecksum;
+    Buffer *copyChecksum;
+    Buffer *repoChecksum;                                           // Checksum repo file (including compression, etc.)
     uint64_t bundleOffset;                                          // Offset in bundle if any
     uint64_t repoSize;
+    uint64_t blockIncrMapSize;                                      // Size of block incremental map (0 if no map)
     Pack *pageChecksumResult;
 } BackupFileResult;
 
-List *backupFile(
-    const String *repoFile, CompressType repoFileCompressType, int repoFileCompressLevel, bool delta, CipherType cipherType,
-    const String *cipherPass, const List *fileList);
+FN_EXTERN List *backupFile(
+    const String *repoFile, uint64_t bundleId, unsigned int blockIncrReference, CompressType repoFileCompressType,
+    int repoFileCompressLevel, CipherType cipherType, const String *cipherPass, const List *fileList);
 
 #endif
