@@ -35,16 +35,16 @@ typedef struct PageChecksum
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-String *
-pageChecksumToLog(const PageChecksum *this)
+FN_EXTERN void
+pageChecksumToLog(const PageChecksum *const this, StringStatic *const debugLog)
 {
-    return strNewFmt("{valid: %s, align: %s}", cvtBoolToConstZ(this->valid), cvtBoolToConstZ(this->align));
+    strStcFmt(debugLog, "{valid: %s, align: %s}", cvtBoolToConstZ(this->valid), cvtBoolToConstZ(this->align));
 }
 
 #define FUNCTION_LOG_PAGE_CHECKSUM_TYPE                                                                                            \
     PageChecksum *
 #define FUNCTION_LOG_PAGE_CHECKSUM_FORMAT(value, buffer, bufferSize)                                                               \
-    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, pageChecksumToLog, buffer, bufferSize)
+    FUNCTION_LOG_OBJECT_FORMAT(value, pageChecksumToLog, buffer, bufferSize)
 
 /***********************************************************************************************************************************
 Count bytes in the input
@@ -224,7 +224,7 @@ pageChecksumResult(THIS_VOID)
 }
 
 /**********************************************************************************************************************************/
-IoFilter *
+FN_EXTERN IoFilter *
 pageChecksumNew(const unsigned int segmentNo, const unsigned int segmentPageTotal, const String *const fileName)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
@@ -237,7 +237,7 @@ pageChecksumNew(const unsigned int segmentNo, const unsigned int segmentPageTota
 
     OBJ_NEW_BEGIN(PageChecksum, .childQty = MEM_CONTEXT_QTY_MAX, .allocQty = MEM_CONTEXT_QTY_MAX)
     {
-        PageChecksum *driver = OBJ_NEW_ALLOC();
+        PageChecksum *const driver = OBJ_NAME(OBJ_NEW_ALLOC(), IoFilter::PageChecksum);
 
         *driver = (PageChecksum)
         {
@@ -273,7 +273,7 @@ pageChecksumNew(const unsigned int segmentNo, const unsigned int segmentPageTota
     FUNCTION_LOG_RETURN(IO_FILTER, this);
 }
 
-IoFilter *
+FN_EXTERN IoFilter *
 pageChecksumNewPack(const Pack *const paramList)
 {
     IoFilter *result = NULL;
