@@ -959,7 +959,7 @@ removeExpiredHistory(InfoBackup *infoBackup, unsigned int repoIdx)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 cmdExpire(void)
 {
     FUNCTION_LOG_VOID(logLevelDebug);
@@ -1044,7 +1044,8 @@ cmdExpire(void)
                         if (cfgOptionIdxTest(cfgOptRepoRetentionFull, repoIdx))
                         {
                             expireTimeBasedBackup(
-                                infoBackup, time(NULL) - (time_t)(cfgOptionUInt(cfgOptRepoRetentionFull) * SEC_PER_DAY), repoIdx);
+                                infoBackup, time(NULL) - (time_t)(cfgOptionIdxUInt(cfgOptRepoRetentionFull, repoIdx) * SEC_PER_DAY),
+                                repoIdx);
                         }
                     }
                     else
