@@ -21,10 +21,10 @@ Repository Get Command
 /***********************************************************************************************************************************
 Write source file to destination IO
 ***********************************************************************************************************************************/
-int
+static int
 storageGetProcess(IoWrite *destination)
 {
-    FUNCTION_LOG_BEGIN(logLevelDebug)
+    FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(IO_READ, destination);
     FUNCTION_LOG_END();
 
@@ -162,7 +162,7 @@ storageGetProcess(IoWrite *destination)
 }
 
 /**********************************************************************************************************************************/
-int
+FN_EXTERN int
 cmdStorageGet(void)
 {
     FUNCTION_LOG_VOID(logLevelDebug);
