@@ -13,7 +13,7 @@ Restore Protocol Handler
 #include "storage/helper.h"
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 restoreFileProtocol(PackRead *const param, ProtocolServer *const server)
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
@@ -34,6 +34,7 @@ restoreFileProtocol(PackRead *const param, ProtocolServer *const server)
         const bool delta = pckReadBoolP(param);
         const bool deltaForce = pckReadBoolP(param);
         const String *const cipherPass = pckReadStrP(param);
+        const StringList *const referenceList = pckReadStrLstP(param);
 
         // Build the file list
         List *fileList = lstNewP(sizeof(RestoreFile));
@@ -41,7 +42,7 @@ restoreFileProtocol(PackRead *const param, ProtocolServer *const server)
         while (!pckReadNullP(param))
         {
             RestoreFile file = {.name = pckReadStrP(param)};
-            file.checksum = pckReadStrP(param);
+            file.checksum = pckReadBinP(param);
             file.size = pckReadU64P(param);
             file.timeModified = pckReadTimeP(param);
             file.mode = pckReadModeP(param);
@@ -55,6 +56,12 @@ restoreFileProtocol(PackRead *const param, ProtocolServer *const server)
                 file.limit = varNewUInt64(pckReadU64P(param));
             }
 
+            // Block incremental
+            file.blockIncrMapSize = pckReadU64P(param);
+
+            if (file.blockIncrMapSize != 0)
+                file.blockIncrSize = pckReadU64P(param);
+
             file.manifestFile = pckReadStrP(param);
 
             lstAdd(fileList, &file);
@@ -62,7 +69,7 @@ restoreFileProtocol(PackRead *const param, ProtocolServer *const server)
 
         // Restore files
         const List *const result = restoreFile(
-            repoFile, repoIdx, repoFileCompressType, copyTimeBegin, delta, deltaForce, cipherPass, fileList);
+            repoFile, repoIdx, repoFileCompressType, copyTimeBegin, delta, deltaForce, cipherPass, referenceList, fileList);
 
         // Return result
         PackWrite *const resultPack = protocolPackNew();
