@@ -42,12 +42,12 @@ Data Types and Structures
 #define FUNCTION_LOG_VERIFY_ARCHIVE_RESULT_TYPE                                                                                    \
     VerifyArchiveResult
 #define FUNCTION_LOG_VERIFY_ARCHIVE_RESULT_FORMAT(value, buffer, bufferSize)                                                       \
-    objToLog(&value, "VerifyArchiveResult", buffer, bufferSize)
+    objNameToLog(&value, "VerifyArchiveResult", buffer, bufferSize)
 
 #define FUNCTION_LOG_VERIFY_BACKUP_RESULT_TYPE                                                                                     \
     VerifyBackupResult
 #define FUNCTION_LOG_VERIFY_BACKUP_RESULT_FORMAT(value, buffer, bufferSize)                                                        \
-    objToLog(&value, "VerifyBackupResult", buffer, bufferSize)
+    objNameToLog(&value, "VerifyBackupResult", buffer, bufferSize)
 
 // Structure for verifying repository info files
 typedef struct VerifyInfoFile
@@ -201,6 +201,8 @@ verifyInfoFile(const String *pathFileName, bool keepFile, const String *cipherPa
         FUNCTION_TEST_PARAM(STRING, cipherPass);                    // Password to open file if encrypted
     FUNCTION_LOG_END();
 
+    FUNCTION_AUDIT_STRUCT();
+
     ASSERT(pathFileName != NULL);
 
     VerifyInfoFile result = {.errorCode = 0};
@@ -224,11 +226,12 @@ verifyInfoFile(const String *pathFileName, bool keepFile, const String *cipherPa
             else
                 ioReadDrain(infoRead);
 
-            PackRead *const filterResult = ioFilterGroupResultP(ioReadFilterGroup(infoRead), CRYPTO_HASH_FILTER_TYPE);
+            const Buffer *const filterResult = pckReadBinP(
+                ioFilterGroupResultP(ioReadFilterGroup(infoRead), CRYPTO_HASH_FILTER_TYPE));
 
             MEM_CONTEXT_PRIOR_BEGIN()
             {
-                result.checksum = pckReadStrP(filterResult);
+                result.checksum = strNewEncode(encodingHex, filterResult);
             }
             MEM_CONTEXT_PRIOR_END();
         }
@@ -487,7 +490,7 @@ verifyManifestFile(
 /***********************************************************************************************************************************
 Check the history in the info files
 ***********************************************************************************************************************************/
-void
+static void
 verifyPgHistory(const InfoPg *archiveInfoPg, const InfoPg *backupInfoPg)
 {
     FUNCTION_TEST_BEGIN();
@@ -542,6 +545,8 @@ verifyCreateArchiveIdRange(VerifyArchiveResult *archiveIdResult, StringList *wal
         FUNCTION_TEST_PARAM_P(UINT, jobErrorTotal);                     // Pointer to the overall job error total
     FUNCTION_TEST_END();
 
+    FUNCTION_AUDIT_HELPER();
+
     ASSERT(archiveIdResult != NULL);
     ASSERT(walFileList != NULL);
 
@@ -564,19 +569,6 @@ verifyCreateArchiveIdRange(VerifyArchiveResult *archiveIdResult, StringList *wal
     {
         String *walSegment = strSubN(strLstGet(walFileList, walFileIdx), 0, WAL_SEGMENT_NAME_SIZE);
 
-        // If walSegment found ends in FF for PG versions 9.2 or less then skip it but log error because it should not exist and
-        // PostgreSQL will ignore it
-        if (archiveIdResult->pgWalInfo.version <= PG_VERSION_92 && strEndsWithZ(walSegment, "FF"))
-        {
-            LOG_INFO_FMT("invalid WAL '%s' for '%s' exists, skipping", strZ(walSegment), strZ(archiveIdResult->archiveId));
-
-            (*jobErrorTotal)++;
-
-            // Remove the file from the original list so no attempt is made to verify it
-            strLstRemoveIdx(walFileList, walFileIdx);
-            continue;
-        }
-
         // The lists are sorted so look ahead to see if this is a duplicate of the next one in the list
         if (walFileIdx + 1 < strLstSize(walFileList))
         {
@@ -753,7 +745,8 @@ verifyArchive(VerifyJobData *const jobData)
                         const String *fileName = strLstGet(jobData->walFileList, 0);
                         const String *filePathName = strNewFmt(
                             STORAGE_REPO_ARCHIVE "/%s/%s/%s", strZ(archiveResult->archiveId), strZ(walPath), strZ(fileName));
-                        String *checksum = strSubN(fileName, WAL_SEGMENT_NAME_SIZE + 1, HASH_TYPE_SHA1_SIZE_HEX);
+                        Buffer *const checksum = bufNewDecode(
+                            encodingHex, strSubN(fileName, WAL_SEGMENT_NAME_SIZE + 1, HASH_TYPE_SHA1_SIZE_HEX));
 
                         // Set up the job
                         ProtocolCommand *command = protocolCommandNew(PROTOCOL_COMMAND_VERIFY_FILE);
@@ -762,7 +755,7 @@ verifyArchive(VerifyJobData *const jobData)
                         pckWriteStrP(param, filePathName);
                         pckWriteBoolP(param, false);
                         pckWriteU32P(param, compressTypeFromName(filePathName));
-                        pckWriteStrP(param, checksum);
+                        pckWriteBinP(param, checksum);
                         pckWriteU64P(param, archiveResult->pgWalInfo.size);
                         pckWriteStrP(param, jobData->walCipherPass);
 
@@ -1005,11 +998,22 @@ verifyBackup(VerifyJobData *const jobData)
                                 pckWriteBoolP(param, false);
                             }
 
-                            pckWriteU32P(param, manifestData(jobData->manifest)->backupOptionCompressType);
-                            // If the checksum is not present in the manifest, it will be calculated by manifest load
-                            pckWriteStrP(param, STR(fileData.checksumSha1));
-                            pckWriteU64P(param, fileData.size);
-                            pckWriteStrP(param, jobData->backupCipherPass);
+                            // Use the repo checksum when present
+                            if (fileData.checksumRepoSha1 != NULL)
+                            {
+                                pckWriteU32P(param, compressTypeNone);
+                                pckWriteBinP(param, BUF(fileData.checksumRepoSha1, HASH_TYPE_SHA1_SIZE));
+                                pckWriteU64P(param, fileData.sizeRepo);
+                                pckWriteStrP(param, NULL);
+                            }
+                            // Else use the file checksum, which may require additional filters, e.g. decompression
+                            else
+                            {
+                                pckWriteU32P(param, manifestData(jobData->manifest)->backupOptionCompressType);
+                                pckWriteBinP(param, BUF(fileData.checksumSha1, HASH_TYPE_SHA1_SIZE));
+                                pckWriteU64P(param, fileData.size);
+                                pckWriteStrP(param, jobData->backupCipherPass);
+                            }
 
                             // Assign job to result (prepend backup label being processed to the key since some files are in a prior
                             // backup)
@@ -1322,6 +1326,8 @@ verifyRender(const List *const archiveIdResultList, const List *const backupResu
         FUNCTION_TEST_PARAM(BOOL, verboseText);                     // Is verbose output requested?
     FUNCTION_TEST_END();
 
+    FUNCTION_AUDIT_HELPER();
+
     ASSERT(archiveIdResultList != NULL);
     ASSERT(backupResultList != NULL);
 
@@ -1711,7 +1717,7 @@ verifyProcess(const bool verboseText)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 cmdVerify(void)
 {
     FUNCTION_LOG_VOID(logLevelDebug);
