@@ -16,6 +16,6 @@ Filter type constant
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-IoFilter *bz2DecompressNew(void);
+FN_EXTERN IoFilter *bz2DecompressNew(void);
 
 #endif
