@@ -16,6 +16,6 @@ Filter type constant
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-IoFilter *gzDecompressNew(void);
+FN_EXTERN IoFilter *gzDecompressNew(void);
 
 #endif
