@@ -42,7 +42,9 @@ static const struct CompressHelperLocal
     IoFilter *(*compressNew)(int);                                  // Function to create new compression filter
     StringId decompressType;                                        // Type of the decompression filter
     IoFilter *(*decompressNew)(void);                               // Function to create new decompression filter
-    int levelDefault;                                               // Default compression level
+    int levelDefault:8;                                             // Default compression level
+    int levelMin:8;                                                 // Minimum compression level
+    int levelMax:8;                                                 // Maximum compression level
 } compressHelperLocal[] =
 {
     {
@@ -58,7 +60,9 @@ static const struct CompressHelperLocal
         .compressNew = bz2CompressNew,
         .decompressType = BZ2_DECOMPRESS_FILTER_TYPE,
         .decompressNew = bz2DecompressNew,
-        .levelDefault = 9,
+        .levelDefault = BZ2_COMPRESS_LEVEL_DEFAULT,
+        .levelMin = BZ2_COMPRESS_LEVEL_MIN,
+        .levelMax = BZ2_COMPRESS_LEVEL_MAX,
     },
     {
         .typeId = STRID5("gz", 0x3470),
@@ -68,7 +72,9 @@ static const struct CompressHelperLocal
         .compressNew = gzCompressNew,
         .decompressType = GZ_DECOMPRESS_FILTER_TYPE,
         .decompressNew = gzDecompressNew,
-        .levelDefault = 6,
+        .levelDefault = GZ_COMPRESS_LEVEL_DEFAULT,
+        .levelMin = GZ_COMPRESS_LEVEL_MIN,
+        .levelMax = GZ_COMPRESS_LEVEL_MAX,
     },
     {
         .typeId = STRID6("lz4", 0x2068c1),
@@ -79,7 +85,9 @@ static const struct CompressHelperLocal
         .compressNew = lz4CompressNew,
         .decompressType = LZ4_DECOMPRESS_FILTER_TYPE,
         .decompressNew = lz4DecompressNew,
-        .levelDefault = 1,
+        .levelDefault = LZ4_COMPRESS_LEVEL_DEFAULT,
+        .levelMin = LZ4_COMPRESS_LEVEL_MIN,
+        .levelMax = LZ4_COMPRESS_LEVEL_MAX,
 #endif
     },
     {
@@ -91,7 +99,9 @@ static const struct CompressHelperLocal
         .compressNew = zstCompressNew,
         .decompressType = ZST_DECOMPRESS_FILTER_TYPE,
         .decompressNew = zstDecompressNew,
-        .levelDefault = 3,
+        .levelDefault = ZST_COMPRESS_LEVEL_DEFAULT,
+        .levelMin = ZST_COMPRESS_LEVEL_MIN,
+        .levelMax = ZST_COMPRESS_LEVEL_MAX,
 #endif
     },
     {
@@ -102,7 +112,7 @@ static const struct CompressHelperLocal
 };
 
 /**********************************************************************************************************************************/
-CompressType
+FN_EXTERN CompressType
 compressTypeEnum(const StringId type)
 {
     FUNCTION_TEST_BEGIN();
@@ -126,7 +136,7 @@ compressTypeEnum(const StringId type)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 compressTypePresent(CompressType type)
 {
     FUNCTION_TEST_BEGIN();
@@ -142,7 +152,7 @@ compressTypePresent(CompressType type)
 }
 
 /**********************************************************************************************************************************/
-const String *
+FN_EXTERN const String *
 compressTypeStr(CompressType type)
 {
     FUNCTION_TEST_BEGIN();
@@ -155,7 +165,7 @@ compressTypeStr(CompressType type)
 }
 
 /**********************************************************************************************************************************/
-CompressType
+FN_EXTERN CompressType
 compressTypeFromName(const String *name)
 {
     FUNCTION_TEST_BEGIN();
@@ -177,7 +187,7 @@ compressTypeFromName(const String *name)
 }
 
 /**********************************************************************************************************************************/
-int
+FN_EXTERN int
 compressLevelDefault(CompressType type)
 {
     FUNCTION_TEST_BEGIN();
@@ -191,7 +201,35 @@ compressLevelDefault(CompressType type)
 }
 
 /**********************************************************************************************************************************/
-IoFilter *
+FN_EXTERN int
+compressLevelMin(CompressType type)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(ENUM, type);
+    FUNCTION_TEST_END();
+
+    ASSERT(type < LENGTH_OF(compressHelperLocal));
+    compressTypePresent(type);
+
+    FUNCTION_TEST_RETURN(INT, compressHelperLocal[type].levelMin);
+}
+
+/**********************************************************************************************************************************/
+FN_EXTERN int
+compressLevelMax(CompressType type)
+{
+    FUNCTION_TEST_BEGIN();
+        FUNCTION_TEST_PARAM(ENUM, type);
+    FUNCTION_TEST_END();
+
+    ASSERT(type < LENGTH_OF(compressHelperLocal));
+    compressTypePresent(type);
+
+    FUNCTION_TEST_RETURN(INT, compressHelperLocal[type].levelMax);
+}
+
+/**********************************************************************************************************************************/
+FN_EXTERN IoFilter *
 compressFilter(CompressType type, int level)
 {
     FUNCTION_TEST_BEGIN();
@@ -207,7 +245,7 @@ compressFilter(CompressType type, int level)
 }
 
 /**********************************************************************************************************************************/
-IoFilter *
+FN_EXTERN IoFilter *
 compressFilterPack(const StringId filterType, const Pack *const filterParam)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
@@ -245,7 +283,7 @@ compressFilterPack(const StringId filterType, const Pack *const filterParam)
 }
 
 /**********************************************************************************************************************************/
-IoFilter *
+FN_EXTERN IoFilter *
 decompressFilter(CompressType type)
 {
     FUNCTION_TEST_BEGIN();
@@ -260,7 +298,7 @@ decompressFilter(CompressType type)
 }
 
 /**********************************************************************************************************************************/
-const String *
+FN_EXTERN const String *
 compressExtStr(CompressType type)
 {
     FUNCTION_TEST_BEGIN();
@@ -273,7 +311,7 @@ compressExtStr(CompressType type)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 compressExtCat(String *file, CompressType type)
 {
     FUNCTION_TEST_BEGIN();
@@ -289,7 +327,7 @@ compressExtCat(String *file, CompressType type)
 }
 
 /**********************************************************************************************************************************/
-String *
+FN_EXTERN String *
 compressExtStrip(const String *file, CompressType type)
 {
     FUNCTION_TEST_BEGIN();
