@@ -13,13 +13,19 @@ Compress IO to the lz4 format.
 /***********************************************************************************************************************************
 Filter type constant
 ***********************************************************************************************************************************/
-#define LZ4_COMPRESS_FILTER_TYPE                                    "lz4Compress"
-    STRING_DECLARE(LZ4_COMPRESS_FILTER_TYPE_STR);
+#define LZ4_COMPRESS_FILTER_TYPE                                    STRID6("lz4-cmp", 0x103436e068c1)
+
+/***********************************************************************************************************************************
+Level constants
+***********************************************************************************************************************************/
+#define LZ4_COMPRESS_LEVEL_DEFAULT                                  1
+#define LZ4_COMPRESS_LEVEL_MIN                                      -5
+#define LZ4_COMPRESS_LEVEL_MAX                                      12
 
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-IoFilter *lz4CompressNew(int level);
+FN_EXTERN IoFilter *lz4CompressNew(int level);
 
 #endif
 
