@@ -18,7 +18,7 @@ Filter type constant
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-IoFilter *lz4DecompressNew(void);
+FN_EXTERN IoFilter *lz4DecompressNew(void);
 
 #endif
 
