@@ -15,10 +15,17 @@ Filter type constant
 ***********************************************************************************************************************************/
 #define ZST_COMPRESS_FILTER_TYPE                                    STRID5("zst-cmp", 0x41a3dd27a0)
 
+/***********************************************************************************************************************************
+Level constants
+***********************************************************************************************************************************/
+#define ZST_COMPRESS_LEVEL_DEFAULT                                  3
+#define ZST_COMPRESS_LEVEL_MIN                                      -7
+#define ZST_COMPRESS_LEVEL_MAX                                      22
+
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-IoFilter *zstCompressNew(int level);
+FN_EXTERN IoFilter *zstCompressNew(int level);
 
 #endif
 
