@@ -80,7 +80,7 @@ typedef struct HttpRequestNewParam
 #define httpRequestNewP(client, verb, path, ...)                                                                                   \
     httpRequestNew(client, verb, path, (HttpRequestNewParam){VAR_PARAM_INIT, __VA_ARGS__})
 
-HttpRequest *httpRequestNew(HttpClient *client, const String *verb, const String *path, HttpRequestNewParam param);
+FN_EXTERN HttpRequest *httpRequestNew(HttpClient *client, const String *verb, const String *path, HttpRequestNewParam param);
 
 /***********************************************************************************************************************************
 Getters/Setters
@@ -94,28 +94,28 @@ typedef struct HttpRequestPub
 } HttpRequestPub;
 
 // Request path
-__attribute__((always_inline)) static inline const String *
+FN_INLINE_ALWAYS const String *
 httpRequestPath(const HttpRequest *const this)
 {
     return THIS_PUB(HttpRequest)->path;
 }
 
 // Request query
-__attribute__((always_inline)) static inline const HttpQuery *
+FN_INLINE_ALWAYS const HttpQuery *
 httpRequestQuery(const HttpRequest *const this)
 {
     return THIS_PUB(HttpRequest)->query;
 }
 
 // Request headers
-__attribute__((always_inline)) static inline const HttpHeader *
+FN_INLINE_ALWAYS const HttpHeader *
 httpRequestHeader(const HttpRequest *const this)
 {
     return THIS_PUB(HttpRequest)->header;
 }
 
 // Request verb
-__attribute__((always_inline)) static inline const String *
+FN_INLINE_ALWAYS const String *
 httpRequestVerb(const HttpRequest *const this)
 {
     return THIS_PUB(HttpRequest)->verb;
@@ -125,13 +125,13 @@ httpRequestVerb(const HttpRequest *const this)
 Functions
 ***********************************************************************************************************************************/
 // Wait for a response from the request
-HttpResponse *httpRequestResponse(HttpRequest *this, bool contentCache);
+FN_EXTERN HttpResponse *httpRequestResponse(HttpRequest *this, bool contentCache);
 
 // Throw an error if the request failed
-FN_NO_RETURN void httpRequestError(const HttpRequest *this, HttpResponse *response);
+FN_EXTERN FN_NO_RETURN void httpRequestError(const HttpRequest *this, HttpResponse *response);
 
 // Move to a new parent mem context
-__attribute__((always_inline)) static inline HttpRequest *
+FN_INLINE_ALWAYS HttpRequest *
 httpRequestMove(HttpRequest *const this, MemContext *const parentNew)
 {
     return objMove(this, parentNew);
@@ -140,7 +140,7 @@ httpRequestMove(HttpRequest *const this, MemContext *const parentNew)
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
-__attribute__((always_inline)) static inline void
+FN_INLINE_ALWAYS void
 httpRequestFree(HttpRequest *const this)
 {
     objFree(this);
@@ -149,11 +149,11 @@ httpRequestFree(HttpRequest *const this)
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-String *httpRequestToLog(const HttpRequest *this);
+FN_EXTERN void httpRequestToLog(const HttpRequest *this, StringStatic *debugLog);
 
 #define FUNCTION_LOG_HTTP_REQUEST_TYPE                                                                                            \
     HttpRequest *
 #define FUNCTION_LOG_HTTP_REQUEST_FORMAT(value, buffer, bufferSize)                                                               \
-    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, httpRequestToLog, buffer, bufferSize)
+    FUNCTION_LOG_OBJECT_FORMAT(value, httpRequestToLog, buffer, bufferSize)
 
 #endif
