@@ -20,20 +20,20 @@ typedef struct HttpSession HttpSession;
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-HttpSession *httpSessionNew(HttpClient *client, IoSession *session);
+FN_EXTERN HttpSession *httpSessionNew(HttpClient *client, IoSession *session);
 
 /***********************************************************************************************************************************
 Functions
 ***********************************************************************************************************************************/
 // Move to a new parent mem context
-__attribute__((always_inline)) static inline HttpSession *
+FN_INLINE_ALWAYS HttpSession *
 httpSessionMove(HttpSession *const this, MemContext *const parentNew)
 {
     return objMove(this, parentNew);
 }
 
 // Work with the session has finished cleanly and it can be reused
-void httpSessionDone(HttpSession *this);
+FN_EXTERN void httpSessionDone(HttpSession *this);
 
 /***********************************************************************************************************************************
 Getters/Setters
@@ -48,15 +48,15 @@ typedef struct HttpSessionIoReadParam
 #define httpSessionIoReadP(this, ...)                                                                                                \
     httpSessionIoRead(this, (HttpSessionIoReadParam){VAR_PARAM_INIT, __VA_ARGS__})
 
-IoRead *httpSessionIoRead(HttpSession *this, HttpSessionIoReadParam param);
+FN_EXTERN IoRead *httpSessionIoRead(HttpSession *this, HttpSessionIoReadParam param);
 
 // Write interface
-IoWrite *httpSessionIoWrite(HttpSession *this);
+FN_EXTERN IoWrite *httpSessionIoWrite(HttpSession *this);
 
 /***********************************************************************************************************************************
 Destructor
 ***********************************************************************************************************************************/
-__attribute__((always_inline)) static inline void
+FN_INLINE_ALWAYS void
 httpSessionFree(HttpSession *const this)
 {
     objFree(this);
@@ -68,6 +68,6 @@ Macros for function logging
 #define FUNCTION_LOG_HTTP_SESSION_TYPE                                                                                             \
     HttpSession *
 #define FUNCTION_LOG_HTTP_SESSION_FORMAT(value, buffer, bufferSize)                                                                \
-    objToLog(value, "HttpSession", buffer, bufferSize)
+    objNameToLog(value, "HttpSession", buffer, bufferSize)
 
 #endif
