@@ -40,20 +40,20 @@ typedef struct SocketClient
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-static String *
-sckClientToLog(const THIS_VOID)
+static void
+sckClientToLog(const THIS_VOID, StringStatic *const debugLog)
 {
     THIS(const SocketClient);
 
-    return strNewFmt(
-        "{host: %s, port: %u, timeoutConnect: %" PRIu64 ", timeoutSession: %" PRIu64 "}", strZ(this->host), this->port,
+    strStcFmt(
+        debugLog, "{host: %s, port: %u, timeoutConnect: %" PRIu64 ", timeoutSession: %" PRIu64 "}", strZ(this->host), this->port,
         this->timeoutConnect, this->timeoutSession);
 }
 
 #define FUNCTION_LOG_SOCKET_CLIENT_TYPE                                                                                            \
     SocketClient *
 #define FUNCTION_LOG_SOCKET_CLIENT_FORMAT(value, buffer, bufferSize)                                                               \
-    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, sckClientToLog, buffer, bufferSize)
+    FUNCTION_LOG_OBJECT_FORMAT(value, sckClientToLog, buffer, bufferSize)
 
 /**********************************************************************************************************************************/
 static IoSession *
@@ -146,7 +146,7 @@ sckClientName(THIS_VOID)
 
     ASSERT(this != NULL);
 
-    FUNCTION_TEST_RETURN(this->name);
+    FUNCTION_TEST_RETURN_CONST(STRING, this->name);
 }
 
 /**********************************************************************************************************************************/
@@ -158,10 +158,10 @@ static const IoClientInterface sckClientInterface =
     .toLog = sckClientToLog,
 };
 
-IoClient *
+FN_EXTERN IoClient *
 sckClientNew(const String *const host, const unsigned int port, const TimeMSec timeoutConnect, const TimeMSec timeoutSession)
 {
-    FUNCTION_LOG_BEGIN(logLevelDebug)
+    FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STRING, host);
         FUNCTION_LOG_PARAM(UINT, port);
         FUNCTION_LOG_PARAM(TIME_MSEC, timeoutConnect);
@@ -172,9 +172,9 @@ sckClientNew(const String *const host, const unsigned int port, const TimeMSec t
 
     IoClient *this = NULL;
 
-    OBJ_NEW_BEGIN(SocketClient)
+    OBJ_NEW_BEGIN(SocketClient, .childQty = MEM_CONTEXT_QTY_MAX, .allocQty = MEM_CONTEXT_QTY_MAX)
     {
-        SocketClient *driver = OBJ_NEW_ALLOC();
+        SocketClient *const driver = OBJ_NAME(OBJ_NEW_ALLOC(), IoClient::SocketClient);
 
         *driver = (SocketClient)
         {
