@@ -31,18 +31,19 @@ typedef struct SocketSession
 /***********************************************************************************************************************************
 Macros for function logging
 ***********************************************************************************************************************************/
-static String *
-sckSessionToLog(const THIS_VOID)
+static void
+sckSessionToLog(const THIS_VOID, StringStatic *const debugLog)
 {
     THIS(const SocketSession);
 
-    return strNewFmt("{fd %d, host: %s, port: %u, timeout: %" PRIu64 "}", this->fd, strZ(this->host), this->port, this->timeout);
+    strStcFmt(
+        debugLog, "{host: %s, port: %u, fd: %d, timeout: %" PRIu64 "}", strZ(this->host), this->port, this->fd, this->timeout);
 }
 
 #define FUNCTION_LOG_SOCKET_SESSION_TYPE                                                                                           \
     SocketSession *
 #define FUNCTION_LOG_SOCKET_SESSION_FORMAT(value, buffer, bufferSize)                                                              \
-    FUNCTION_LOG_STRING_OBJECT_FORMAT(value, sckSessionToLog, buffer, bufferSize)
+    FUNCTION_LOG_OBJECT_FORMAT(value, sckSessionToLog, buffer, bufferSize)
 
 /***********************************************************************************************************************************
 Free connection
@@ -162,10 +163,10 @@ static const IoSessionInterface sckSessionInterface =
     .toLog = sckSessionToLog,
 };
 
-IoSession *
+FN_EXTERN IoSession *
 sckSessionNew(IoSessionRole role, int fd, const String *host, unsigned int port, TimeMSec timeout)
 {
-    FUNCTION_LOG_BEGIN(logLevelDebug)
+    FUNCTION_LOG_BEGIN(logLevelDebug);
         FUNCTION_LOG_PARAM(STRING_ID, role);
         FUNCTION_LOG_PARAM(INT, fd);
         FUNCTION_LOG_PARAM(STRING, host);
@@ -180,7 +181,7 @@ sckSessionNew(IoSessionRole role, int fd, const String *host, unsigned int port,
 
     OBJ_NEW_BEGIN(SocketSession, .childQty = MEM_CONTEXT_QTY_MAX, .allocQty = MEM_CONTEXT_QTY_MAX, .callbackQty = 1)
     {
-        SocketSession *driver = OBJ_NEW_ALLOC();
+        SocketSession *const driver = OBJ_NAME(OBJ_NEW_ALLOC(), IoSession::SocketSession);
 
         String *name = strNewFmt("%s:%u", strZ(host), port);
 
