@@ -12,18 +12,18 @@ TLS Common
 Functions
 ***********************************************************************************************************************************/
 // Convert an ASN1 string used in certificates to a String
-String *tlsAsn1ToStr(ASN1_STRING *nameAsn1);
+FN_EXTERN String *tlsAsn1ToStr(ASN1_STRING *nameAsn1);
 
 // Get common name from a certificate
-String *tlsCertCommonName(X509 *certificate);
+FN_EXTERN String *tlsCertCommonName(X509 *certificate);
 
 // Reject embedded nulls in certificate common or alternative name to prevent attacks like CVE-2009-4034
-void tlsCertNameVerify(const String *name);
+FN_EXTERN void tlsCertNameVerify(const String *name);
 
 // Load certificate and key and check that they match
-void tlsCertKeyLoad(SSL_CTX *context, const String *certFile, const String *keyFile);
+FN_EXTERN void tlsCertKeyLoad(SSL_CTX *context, const String *certFile, const String *keyFile);
 
 // Create TLS context
-SSL_CTX *tlsContext(void);
+FN_EXTERN SSL_CTX *tlsContext(void);
 
 #endif
