@@ -38,22 +38,49 @@ Space is reserved for this many allocations when a context is created.  When mor
 ***********************************************************************************************************************************/
 #define MEM_CONTEXT_ALLOC_INITIAL_SIZE                              4
 
+/***********************************************************************************************************************************
+Functions and macros to audit a mem context by detecting new child contexts/allocations that were created begin the begin/end but
+are not the expected return type.
+***********************************************************************************************************************************/
+#if defined(DEBUG)
+    typedef struct MemContextAuditState
+    {
+        MemContext *memContext;                                     // Mem context to audit
+
+        bool returnTypeAny;                                         // Skip auditing for this mem context
+        uint64_t sequenceContextNew;                                // Max sequence for new contexts at beginning
+    } MemContextAuditState;
+
+    // Begin the audit
+    FN_EXTERN void memContextAuditBegin(MemContextAuditState *state);
+
+    // End the audit and make sure the return type is as expected
+    FN_EXTERN void memContextAuditEnd(const MemContextAuditState *state, const char *returnTypeDefault);
+
+    // Rename a mem context using the extra allocation pointer
+    #define MEM_CONTEXT_AUDIT_ALLOC_EXTRA_NAME(this, name)          memContextAuditAllocExtraName(this, #name)
+
+    FN_EXTERN void *memContextAuditAllocExtraName(void *allocExtra, const char *name);
+#else
+    #define MEM_CONTEXT_AUDIT_ALLOC_EXTRA_NAME(this, name)          this
+#endif
+
 /***********************************************************************************************************************************
 Memory management functions
 
 All these functions operate in the current memory context, including memResize() and memFree().
 ***********************************************************************************************************************************/
 // Allocate memory in the current memory context
-void *memNew(size_t size);
+FN_EXTERN void *memNew(size_t size);
 
 // Allocate requested number of pointers and initialize them to NULL
-void *memNewPtrArray(size_t size);
+FN_EXTERN void *memNewPtrArray(size_t size);
 
 // Reallocate to the new size.  Original buffer pointer is undefined on return.
-void *memResize(const void *buffer, size_t size);
+FN_EXTERN void *memResize(const void *buffer, size_t size);
 
 // Free memory allocation
-void memFree(void *buffer);
+FN_EXTERN void memFree(void *buffer);
 
 /***********************************************************************************************************************************
 Ensure that the prior memory context is restored after the block executes (even on error)
@@ -225,67 +252,68 @@ typedef struct MemContextNewParam
         memContextNew((MemContextNewParam){VAR_PARAM_INIT, __VA_ARGS__})
 #endif
 
-MemContext *memContextNew(
+FN_EXTERN MemContext *memContextNew(
 #ifdef DEBUG
     const char *name,
 #endif
     MemContextNewParam param);
 
 // Switch to a context making it the current mem context
-void memContextSwitch(MemContext *this);
+FN_EXTERN void memContextSwitch(MemContext *this);
 
 // Switch back to the context that was current before the last switch. If the last function called was memContextNewP(), then
 // memContextKeep()/memContextDiscard() must be called before calling memContextSwitchBack(), otherwise an error will occur in
 // debug builds and the behavior is undefined in production builds.
-void memContextSwitchBack(void);
+FN_EXTERN void memContextSwitchBack(void);
 
 // Keep a context created by memContextNewP() so that it will not be automatically freed if an error occurs. If the context was
 // switched after the call to memContextNewP(), then it must be switched back before calling memContextKeep() or an error will occur
 // in debug builds and the behavior is undefined in production builds.
-void memContextKeep(void);
+FN_EXTERN void memContextKeep(void);
 
 // Discard a context created by memContextNewP(). If the context was switched after the call to memContextNewP(), then it must be
 // switched back before calling memContextDiscard() or an error will occur in debug builds and the behavior is undefined in
 // production builds.
-void memContextDiscard(void);
+FN_EXTERN void memContextDiscard(void);
 
 // Move mem context to a new parent. This is generally used to move objects to a new context once they have been successfully
 // created.
-void memContextMove(MemContext *this, MemContext *parentNew);
+FN_EXTERN void memContextMove(MemContext *this, MemContext *parentNew);
 
 // Set a function that will be called when this mem context is freed
-void memContextCallbackSet(MemContext *this, void (*callbackFunction)(void *), void *);
+FN_EXTERN void memContextCallbackSet(MemContext *this, void (*callbackFunction)(void *), void *);
 
 // Clear the callback function so it won't be called when the mem context is freed.  This is usually done in the object free method
 // after resources have been freed but before memContextFree() is called.  The goal is to prevent the object free method from being
 // called more than once.
-void memContextCallbackClear(MemContext *this);
+FN_EXTERN void memContextCallbackClear(MemContext *this);
 
 // Free a memory context
-void memContextFree(MemContext *this);
+FN_EXTERN void memContextFree(MemContext *this);
 
 /***********************************************************************************************************************************
 Memory context getters
 ***********************************************************************************************************************************/
 // Pointer to the extra memory allocated with the mem context
-void *memContextAllocExtra(MemContext *this);
+FN_EXTERN void *memContextAllocExtra(MemContext *this);
 
 // Get mem context using pointer to the memory allocated with the mem context
-MemContext *memContextFromAllocExtra(void *allocExtra);
-const MemContext *memContextConstFromAllocExtra(const void *allocExtra);
+FN_EXTERN MemContext *memContextFromAllocExtra(void *allocExtra);
 
 // Current memory context
-MemContext *memContextCurrent(void);
+FN_EXTERN MemContext *memContextCurrent(void);
 
 // Prior context, i.e. the context that was current before the last memContextSwitch()
-MemContext *memContextPrior(void);
+FN_EXTERN MemContext *memContextPrior(void);
 
 // "top" context.  This context is created at initialization and is always present, i.e. it is never freed.  The top context is a
 // good place to put long-lived mem contexts since they won't be automatically freed until the program exits.
-MemContext *memContextTop(void);
+FN_EXTERN MemContext *memContextTop(void);
 
 // Get total size of mem context and all children
-size_t memContextSize(const MemContext *this);
+#ifdef DEBUG
+    FN_EXTERN size_t memContextSize(const MemContext *this);
+#endif // DEBUG
 
 /***********************************************************************************************************************************
 Macros for function logging
@@ -293,12 +321,12 @@ Macros for function logging
 #define FUNCTION_LOG_MEM_CONTEXT_TYPE                                                                                              \
     MemContext *
 #define FUNCTION_LOG_MEM_CONTEXT_FORMAT(value, buffer, bufferSize)                                                                 \
-    objToLog(value, "MemContext", buffer, bufferSize)
+    objNameToLog(value, "MemContext", buffer, bufferSize)
 
 /***********************************************************************************************************************************
 Internal functions
 ***********************************************************************************************************************************/
 // Clean up mem contexts after an error.  Should only be called from error handling routines.
-void memContextClean(unsigned int tryDepth);
+FN_EXTERN void memContextClean(unsigned int tryDepth, bool fatal);
 
 #endif
