@@ -62,11 +62,13 @@ cfgLoadLogSetting(void)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 cfgLoadUpdateOption(void)
 {
     FUNCTION_LOG_VOID(logLevelTrace);
 
+    FUNCTION_AUDIT_HELPER();
+
     // Make sure the repo option is set for the stanza-delete command when more than one repo is configured or the first configured
     // repo is not key 1.
     if (!cfgCommandHelp() && cfgOptionValid(cfgOptRepo) && cfgCommand() == cfgCmdStanzaDelete &&
@@ -288,6 +290,20 @@ cfgLoadUpdateOption(void)
         }
     }
 
+    // Set default upload chunk size if not set
+    if (cfgOptionValid(cfgOptRepoStorageUploadChunkSize))
+    {
+        for (unsigned int repoIdx = 0; repoIdx < cfgOptionGroupIdxTotal(cfgOptGrpRepo); repoIdx++)
+        {
+            if (!cfgOptionIdxTest(cfgOptRepoStorageUploadChunkSize, repoIdx))
+            {
+                cfgOptionIdxSet(
+                    cfgOptRepoStorageUploadChunkSize, repoIdx, cfgSourceDefault,
+                    VARINT64((cfgOptionIdxStrId(cfgOptRepoType, repoIdx) == CFGOPTVAL_REPO_TYPE_S3 ? 5 : 4) * 1024 * 1024));
+            }
+        }
+    }
+
     // Set pg-host-port/repo-host-port default when pg-host-type/repo-host-type is tls. ??? This should be handled in the parser but
     // it requires a default that depends on another option value and that is not currently possible.
     #define HOST_PORT_TLS                                           8432
@@ -343,19 +359,33 @@ cfgLoadUpdateOption(void)
     if (cfgOptionValid(cfgOptCompressType))
         compressTypePresent(compressTypeEnum(cfgOptionStrId(cfgOptCompressType)));
 
-    // Update compress-level default based on the compression type
-    if (cfgOptionValid(cfgOptCompressLevel) && cfgOptionSource(cfgOptCompressLevel) == cfgSourceDefault)
+    // Update compress-level default based on the compression type. Also check that level range is valid per compression type.
+    if (cfgOptionValid(cfgOptCompressLevel))
     {
-        cfgOptionSet(
-            cfgOptCompressLevel, cfgSourceDefault,
-            VARINT64(compressLevelDefault(compressTypeEnum(cfgOptionStrId(cfgOptCompressType)))));
+        const CompressType compressType = compressTypeEnum(cfgOptionStrId(cfgOptCompressType));
+
+        if (cfgOptionSource(cfgOptCompressLevel) == cfgSourceDefault)
+        {
+            cfgOptionSet(cfgOptCompressLevel, cfgSourceDefault, VARINT64(compressLevelDefault(compressType)));
+        }
+        else if (compressType != compressTypeNone)
+        {
+            if (cfgOptionInt(cfgOptCompressLevel) < compressLevelMin(compressType) ||
+                cfgOptionInt(cfgOptCompressLevel) > compressLevelMax(compressType))
+            {
+                THROW_FMT(
+                    OptionInvalidValueError,
+                    "'%d' is out of range for '" CFGOPT_COMPRESS_LEVEL "' option when '" CFGOPT_COMPRESS_TYPE "' option = '%s'",
+                    cfgOptionInt(cfgOptCompressLevel), strZ(strIdToStr(cfgOptionStrId(cfgOptCompressType))));
+            }
+        }
     }
 
     FUNCTION_LOG_RETURN_VOID();
 }
 
 /**********************************************************************************************************************************/
-String *
+FN_EXTERN String *
 cfgLoadLogFileName(const ConfigCommandRole commandRole)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
@@ -391,7 +421,7 @@ cfgLoadLogFileName(const ConfigCommandRole commandRole)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 cfgLoadLogFile(void)
 {
     if (cfgLogFile() && !cfgCommandHelp())
@@ -407,7 +437,7 @@ cfgLoadLogFile(void)
 }
 
 /**********************************************************************************************************************************/
-void
+FN_EXTERN void
 cfgLoad(unsigned int argListSize, const char *argList[])
 {
     FUNCTION_LOG_BEGIN(logLevelDebug);
