@@ -35,10 +35,10 @@ typedef void InfoSaveCallback(void *data, const String *sectionNext, InfoSave *i
 /***********************************************************************************************************************************
 Constructors
 ***********************************************************************************************************************************/
-Info *infoNew(const String *cipherPassSub);
+FN_EXTERN Info *infoNew(const String *cipherPassSub);
 
 // Create new object and load contents from a file
-Info *infoNewLoad(IoRead *read, InfoLoadNewCallback *callbackFunction, void *callbackData);
+FN_EXTERN Info *infoNewLoad(IoRead *read, InfoLoadNewCallback *callbackFunction, void *callbackData);
 
 /***********************************************************************************************************************************
 Getters/Setters
@@ -50,16 +50,16 @@ typedef struct InfoPub
 } InfoPub;
 
 // Cipher passphrase if set
-__attribute__((always_inline)) static inline const String *
+FN_INLINE_ALWAYS const String *
 infoCipherPass(const Info *const this)
 {
     return THIS_PUB(Info)->cipherPass;
 }
 
-void infoCipherPassSet(Info *this, const String *cipherPass);
+FN_EXTERN void infoCipherPassSet(Info *this, const String *cipherPass);
 
 // pgBackRest version
-__attribute__((always_inline)) static inline const String *
+FN_INLINE_ALWAYS const String *
 infoBackrestVersion(const Info *const this)
 {
     return THIS_PUB(Info)->backrestVersion;
@@ -69,19 +69,19 @@ infoBackrestVersion(const Info *const this)
 Functions
 ***********************************************************************************************************************************/
 // Save to file
-void infoSave(Info *this, IoWrite *write, InfoSaveCallback *callbackFunction, void *callbackData);
+FN_EXTERN void infoSave(Info *this, IoWrite *write, InfoSaveCallback *callbackFunction, void *callbackData);
 
 // Check if the section should be saved
-bool infoSaveSection(InfoSave *infoSaveData, const char *section, const String *sectionNext);
+FN_EXTERN bool infoSaveSection(InfoSave *infoSaveData, const char *section, const String *sectionNext);
 
 // Save a JSON formatted value and update checksum
-void infoSaveValue(InfoSave *infoSaveData, const char *section, const char *key, const String *jsonValue);
+FN_EXTERN void infoSaveValue(InfoSave *infoSaveData, const char *section, const char *key, const String *jsonValue);
 
 /***********************************************************************************************************************************
 Helper functions
 ***********************************************************************************************************************************/
 // Load info file(s) and throw error for each attempt if none are successful
-void infoLoad(const String *error, InfoLoadCallback *callbackFunction, void *callbackData);
+FN_EXTERN void infoLoad(const String *error, InfoLoadCallback *callbackFunction, void *callbackData);
 
 /***********************************************************************************************************************************
 Macros for function logging
@@ -89,11 +89,11 @@ Macros for function logging
 #define FUNCTION_LOG_INFO_TYPE                                                                                                     \
     Info *
 #define FUNCTION_LOG_INFO_FORMAT(value, buffer, bufferSize)                                                                        \
-    objToLog(value, "Info", buffer, bufferSize)
+    objNameToLog(value, "Info", buffer, bufferSize)
 
 #define FUNCTION_LOG_INFO_SAVE_TYPE                                                                                                \
     InfoSave *
 #define FUNCTION_LOG_INFO_SAVE_FORMAT(value, buffer, bufferSize)                                                                   \
-    objToLog(value, "InfoSave", buffer, bufferSize)
+    objNameToLog(value, "InfoSave", buffer, bufferSize)
 
 #endif
