@@ -42,7 +42,7 @@ Macros for function logging
 #define FUNCTION_LOG_STORAGE_WRITE_GCS_TYPE                                                                                        \
     StorageWriteGcs *
 #define FUNCTION_LOG_STORAGE_WRITE_GCS_FORMAT(value, buffer, bufferSize)                                                           \
-    objToLog(value, "StorageWriteGcs", buffer, bufferSize)
+    objNameToLog(value, "StorageWriteGcs", buffer, bufferSize)
 
 /***********************************************************************************************************************************
 Open the file
@@ -60,12 +60,12 @@ storageWriteGcsOpen(THIS_VOID)
     ASSERT(this->chunkBuffer == NULL);
 
     // Allocate the chunk buffer
-    MEM_CONTEXT_BEGIN(THIS_MEM_CONTEXT())
+    MEM_CONTEXT_OBJ_BEGIN(this)
     {
         this->chunkBuffer = bufNew(this->chunkSize);
-        this->md5hash = cryptoHashNew(HASH_TYPE_MD5_STR);
+        this->md5hash = cryptoHashNew(hashTypeMd5);
     }
-    MEM_CONTEXT_END();
+    MEM_CONTEXT_OBJ_END();
 
     FUNCTION_LOG_RETURN_VOID();
 }
@@ -74,43 +74,47 @@ storageWriteGcsOpen(THIS_VOID)
 Verify upload
 ***********************************************************************************************************************************/
 static void
-storageWriteGcsVerify(StorageWriteGcs *this, HttpResponse *response)
+storageWriteGcsVerify(StorageWriteGcs *const this, HttpResponse *const response)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(STORAGE_WRITE_GCS, this);
         FUNCTION_LOG_PARAM(HTTP_RESPONSE, response);
     FUNCTION_LOG_END();
 
-    KeyValue *content = jsonToKv(strNewBuf(httpResponseContent(response)));
-
-    // Check the md5 hash
-    const String *md5base64 = varStr(kvGet(content, GCS_JSON_MD5_HASH_VAR));
-    CHECK(FormatError, md5base64 != NULL, "MD5 missing");
-
-    const String *md5actual = bufHex(bufNewDecode(encodeBase64, md5base64));
-    const String *md5expected = pckReadStrP(pckReadNew(ioFilterResult(this->md5hash)));
-
-    if (!strEq(md5actual, md5expected))
+    MEM_CONTEXT_TEMP_BEGIN()
     {
-        THROW_FMT(
-            FormatError, "expected md5 '%s' for '%s' but actual is '%s'", strZ(md5expected), strZ(this->interface.name),
-            strZ(md5actual));
-    }
+        KeyValue *const content = varKv(jsonToVar(strNewBuf(httpResponseContent(response))));
 
-    // Check the size when available
-    const String *sizeStr = varStr(kvGet(content, GCS_JSON_SIZE_VAR));
+        // Check the md5 hash
+        const String *const md5base64 = varStr(kvGet(content, GCS_JSON_MD5_HASH_VAR));
+        CHECK(FormatError, md5base64 != NULL, "MD5 missing");
 
-    if (sizeStr != NULL)
-    {
-        uint64_t size = cvtZToUInt64(strZ(sizeStr));
+        const Buffer *const md5actual = bufNewDecode(encodingBase64, md5base64);
+        const Buffer *const md5expected = pckReadBinP(pckReadNew(ioFilterResult(this->md5hash)));
 
-        if (size != this->uploadTotal)
+        if (!bufEq(md5actual, md5expected))
         {
             THROW_FMT(
-                FormatError, "expected size %" PRIu64 " for '%s' but actual is %" PRIu64, size, strZ(this->interface.name),
-                this->uploadTotal);
+                FormatError, "expected md5 '%s' for '%s' but actual is '%s'", strZ(strNewEncode(encodingHex, md5expected)),
+                strZ(this->interface.name), strZ(strNewEncode(encodingHex, md5actual)));
+        }
+
+        // Check the size when available
+        const String *const sizeStr = varStr(kvGet(content, GCS_JSON_SIZE_VAR));
+
+        if (sizeStr != NULL)
+        {
+            const uint64_t size = cvtZToUInt64(strZ(sizeStr));
+
+            if (size != this->uploadTotal)
+            {
+                THROW_FMT(
+                    FormatError, "expected size %" PRIu64 " for '%s' but actual is %" PRIu64, size, strZ(this->interface.name),
+                    this->uploadTotal);
+            }
         }
     }
+    MEM_CONTEXT_TEMP_END();
 
     FUNCTION_LOG_RETURN_VOID();
 }
@@ -119,7 +123,7 @@ storageWriteGcsVerify(StorageWriteGcs *this, HttpResponse *response)
 Flush bytes to upload chunk
 ***********************************************************************************************************************************/
 static void
-storageWriteGcsBlock(StorageWriteGcs *this, bool done)
+storageWriteGcsBlock(StorageWriteGcs *const this, const bool done)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
         FUNCTION_LOG_PARAM(STORAGE_WRITE_GCS, this);
@@ -131,12 +135,13 @@ storageWriteGcsBlock(StorageWriteGcs *this, bool done)
     // If there is an outstanding async request then wait for the response to ensure the request did not error
     if (this->request != NULL)
     {
-        HttpResponse *response = storageGcsResponseP(this->request, .allowIncomplete = !done);
+        HttpResponse *const response = storageGcsResponseP(this->request, .allowIncomplete = !done);
 
         // If done then verify the md5 checksum
         if (done)
             storageWriteGcsVerify(this, response);
 
+        httpResponseFree(response);
         httpRequestFree(this->request);
         this->request = NULL;
     }
@@ -172,12 +177,12 @@ storageWriteGcsBlockAsync(StorageWriteGcs *this, bool done)
         {
             HttpResponse *response = storageGcsRequestP(this->storage, HTTP_VERB_POST_STR, .upload = true, .query = query);
 
-            MEM_CONTEXT_BEGIN(THIS_MEM_CONTEXT())
+            MEM_CONTEXT_OBJ_BEGIN(this)
             {
                 this->uploadId = strDup(httpHeaderGet(httpResponseHeader(response), GCS_HEADER_UPLOAD_ID_STR));
                 CHECK(FormatError, this->uploadId != NULL, "upload id missing");
             }
-            MEM_CONTEXT_END();
+            MEM_CONTEXT_OBJ_END();
         }
 
         // Add data to md5 hash
@@ -190,7 +195,7 @@ storageWriteGcsBlockAsync(StorageWriteGcs *this, bool done)
             strNewFmt(
                 HTTP_HEADER_CONTENT_RANGE_BYTES " %" PRIu64 "-%" PRIu64 "/%s", this->uploadTotal,
                 this->uploadTotal + bufUsed(this->chunkBuffer) - 1,
-                done ? strZ(strNewFmt("%" PRIu64, this->uploadTotal + bufUsed(this->chunkBuffer))) : "*"));
+                done ? zNewFmt("%" PRIu64, this->uploadTotal + bufUsed(this->chunkBuffer)) : "*"));
 
         httpQueryAdd(query, GCS_QUERY_UPLOAD_ID_STR, this->uploadId);
 
@@ -198,13 +203,13 @@ storageWriteGcsBlockAsync(StorageWriteGcs *this, bool done)
         if (done)
             httpQueryAdd(query, GCS_QUERY_FIELDS_STR, GCS_QUERY_FIELDS_VALUE_STR);
 
-        MEM_CONTEXT_BEGIN(THIS_MEM_CONTEXT())
+        MEM_CONTEXT_OBJ_BEGIN(this)
         {
             this->request = storageGcsRequestAsyncP(
                 this->storage, HTTP_VERB_PUT_STR, .upload = true, .noAuth = true, .header = header, .query = query,
                 .content = this->chunkBuffer);
         }
-        MEM_CONTEXT_END();
+        MEM_CONTEXT_OBJ_END();
 
         this->uploadTotal += bufUsed(this->chunkBuffer);
     }
@@ -314,7 +319,7 @@ storageWriteGcsClose(THIS_VOID)
 }
 
 /**********************************************************************************************************************************/
-StorageWrite *
+FN_EXTERN StorageWrite *
 storageWriteGcsNew(StorageGcs *storage, const String *name, size_t chunkSize)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
@@ -328,9 +333,9 @@ storageWriteGcsNew(StorageGcs *storage, const String *name, size_t chunkSize)
 
     StorageWrite *this = NULL;
 
-    OBJ_NEW_BEGIN(StorageWriteGcs)
+    OBJ_NEW_BEGIN(StorageWriteGcs, .childQty = MEM_CONTEXT_QTY_MAX, .allocQty = MEM_CONTEXT_QTY_MAX)
     {
-        StorageWriteGcs *driver = OBJ_NEW_ALLOC();
+        StorageWriteGcs *const driver = OBJ_NAME(OBJ_NEW_ALLOC(), StorageWrite::StorageWriteGcs);
 
         *driver = (StorageWriteGcs)
         {
@@ -345,6 +350,7 @@ storageWriteGcsNew(StorageGcs *storage, const String *name, size_t chunkSize)
                 .createPath = true,
                 .syncFile = true,
                 .syncPath = true,
+                .truncate = true,
 
                 .ioInterface = (IoWriteInterface)
                 {
