@@ -32,38 +32,34 @@ Functions
 // Initialize dry-run for the current command. No writes are allowed until dry-run has been initialized and no writes are allowed
 // after initialization if dry-run is true. Note that storageLocalWrite() is exempt from this rule. The primary purpose is to
 // prevent damage to the repository from an error in dry-run coding in the individual commands.
-void storageHelperDryRunInit(bool dryRun);
+FN_EXTERN void storageHelperDryRunInit(bool dryRun);
 
 // Initialize helpers to create storage other than built-in Posix
-void storageHelperInit(const StorageHelper *helperList);
+FN_EXTERN void storageHelperInit(const StorageHelper *helperList);
 
 // Local storage object. Writable local storage should be used very sparingly. If writes are not needed then always use
 // storageLocal() or a specific storage object instead.
-const Storage *storageLocal(void);
-const Storage *storageLocalWrite(void);
+FN_EXTERN const Storage *storageLocal(void);
+FN_EXTERN const Storage *storageLocalWrite(void);
 
 // PostgreSQL storage by cfgOptGrpPg index
-const Storage *storagePgIdx(unsigned int pgIdx);
-const Storage *storagePgIdxWrite(unsigned int pgIdx);
+FN_EXTERN const Storage *storagePgIdx(unsigned int pgIdx);
+FN_EXTERN const Storage *storagePgIdxWrite(unsigned int pgIdx);
 
 // PostgreSQL storage default (calculated from the pg option, when set, or the first cfgOptGrpPg index)
-const Storage *storagePg(void);
-const Storage *storagePgWrite(void);
+FN_EXTERN const Storage *storagePg(void);
+FN_EXTERN const Storage *storagePgWrite(void);
 
 // Repository storage by cfgOptGrpRepo index
-const Storage *storageRepoIdx(unsigned int repoIdx);
-const Storage *storageRepoIdxWrite(unsigned int repoIdx);
+FN_EXTERN const Storage *storageRepoIdx(unsigned int repoIdx);
+FN_EXTERN const Storage *storageRepoIdxWrite(unsigned int repoIdx);
 
 // Repository storage default (calculated from the repo option, when set, or the first cfgOptGrpPg index)
-const Storage *storageRepo(void);
-const Storage *storageRepoWrite(void);
+FN_EXTERN const Storage *storageRepo(void);
+FN_EXTERN const Storage *storageRepoWrite(void);
 
 // Spool storage
-const Storage *storageSpool(void);
-const Storage *storageSpoolWrite(void);
-
-// Free all storage helper objects. This should be done on any config load to ensure that stanza changes are honored. ?? Currently
-// this is only done in testing, but in the future it will likely be done in production as well.
-void storageHelperFree(void);
+FN_EXTERN const Storage *storageSpool(void);
+FN_EXTERN const Storage *storageSpoolWrite(void);
 
 #endif
