@@ -23,10 +23,10 @@ Macros for function logging
 #define FUNCTION_LOG_STORAGE_READ_INTERFACE_TYPE                                                                                   \
     StorageReadInterface
 #define FUNCTION_LOG_STORAGE_READ_INTERFACE_FORMAT(value, buffer, bufferSize)                                                      \
-    objToLog(&value, "StorageReadInterface", buffer, bufferSize)
+    objNameToLog(&value, "StorageReadInterface", buffer, bufferSize)
 
 /**********************************************************************************************************************************/
-StorageRead *
+FN_EXTERN StorageRead *
 storageReadNew(void *driver, const StorageReadInterface *interface)
 {
     FUNCTION_LOG_BEGIN(logLevelTrace);
@@ -34,6 +34,8 @@ storageReadNew(void *driver, const StorageReadInterface *interface)
         FUNCTION_LOG_PARAM_P(STORAGE_READ_INTERFACE, interface);
     FUNCTION_LOG_END();
 
+    FUNCTION_AUDIT_HELPER();
+
     ASSERT(driver != NULL);
     ASSERT(interface != NULL);
 
@@ -56,10 +58,11 @@ storageReadNew(void *driver, const StorageReadInterface *interface)
 }
 
 /**********************************************************************************************************************************/
-String *
-storageReadToLog(const StorageRead *this)
+FN_EXTERN void
+storageReadToLog(const StorageRead *const this, StringStatic *const debugLog)
 {
-    return strNewFmt(
-        "{type: %s, name: %s, ignoreMissing: %s}", strZ(strIdToStr(storageReadType(this))), strZ(strToLog(storageReadName(this))),
-        cvtBoolToConstZ(storageReadIgnoreMissing(this)));
+    strStcCat(debugLog, "{type: ");
+    strStcResultSizeInc(debugLog, strIdToLog(storageReadType(this), strStcRemains(debugLog), strStcRemainsSize(debugLog)));
+    strStcFmt(
+        debugLog, ", name: %s, ignoreMissing: %s}", strZ(storageReadName(this)), cvtBoolToConstZ(storageReadIgnoreMissing(this)));
 }
