@@ -16,7 +16,7 @@ Get the catalog version
 ***********************************************************************************************************************************/
 #if PG_VERSION > PG_VERSION_MAX
 
-#elif PG_VERSION >= PG_VERSION_90
+#elif PG_VERSION >= PG_VERSION_93
 
 #define HRN_PG_INTERFACE_CATALOG_VERSION(version)                                                                                  \
     uint32_t                                                                                                                       \
@@ -56,34 +56,6 @@ Create a pg_control file
         };                                                                                                                         \
     }
 
-#elif PG_VERSION >= PG_VERSION_90
-
-#define HRN_PG_INTERFACE_CONTROL_TEST(version)                                                                                     \
-    void                                                                                                                           \
-    hrnPgInterfaceControl##version(PgControl pgControl, unsigned char *buffer)                                                     \
-    {                                                                                                                              \
-        ASSERT(buffer != NULL);                                                                                                    \
-        ASSERT(!pgControl.pageChecksum);                                                                                           \
-                                                                                                                                   \
-        *(ControlFileData *)buffer = (ControlFileData)                                                                             \
-        {                                                                                                                          \
-            .system_identifier = pgControl.systemId,                                                                               \
-            .pg_control_version = PG_CONTROL_VERSION,                                                                              \
-            .catalog_version_no = pgControl.catalogVersion,                                                                        \
-            .checkPoint =                                                                                                          \
-            {                                                                                                                      \
-                .xlogid = (uint32_t)(pgControl.checkpoint >> 32),                                                                  \
-                .xrecoff = (uint32_t)(pgControl.checkpoint & 0xFFFFFFFF),                                                          \
-            },                                                                                                                     \
-            .checkPointCopy =                                                                                                      \
-            {                                                                                                                      \
-                .ThisTimeLineID = pgControl.timeline,                                                                              \
-            },                                                                                                                     \
-            .blcksz = pgControl.pageSize,                                                                                          \
-            .xlog_seg_size = pgControl.walSegmentSize,                                                                             \
-        };                                                                                                                         \
-    }
-
 #endif
 
 /***********************************************************************************************************************************
@@ -91,7 +63,7 @@ Create a WAL file
 ***********************************************************************************************************************************/
 #if PG_VERSION > PG_VERSION_MAX
 
-#elif PG_VERSION >= PG_VERSION_90
+#elif PG_VERSION >= PG_VERSION_93
 
 #define HRN_PG_INTERFACE_WAL_TEST(version)                                                                                         \
     void                                                                                                                           \
