@@ -96,6 +96,18 @@ testRun(void)
 
         cfgOptionSet(cfgOptFilter, cfgSourceParam, NULL);
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("exact repo path");
+
+        StringList *argListTmp = strLstDup(argList);
+        strLstAddZ(argListTmp, TEST_PATH "/repo");
+        HRN_CFG_LOAD(cfgCmdRepoLs, argListTmp);
+
+        output = bufNew(0);
+        cfgOptionSet(cfgOptOutput, cfgSourceParam, VARUINT64(CFGOPTVAL_OUTPUT_TEXT));
+        TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "empty directory (text)");
+        TEST_RESULT_STR_Z(strNewBuf(output), "", "check output");
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("add path and file");
 
@@ -157,10 +169,42 @@ testRun(void)
         TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "filter");
         TEST_RESULT_STR_Z(strNewBuf(output), "aaa\n", "check output");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("error on /");
+
+        argListTmp = strLstDup(argList);
+        strLstAddZ(argListTmp, "/");
+        HRN_CFG_LOAD(cfgCmdRepoLs, argListTmp);
+
+        TEST_ERROR(
+            storageListRender(ioBufferWriteNew(output)), ParamInvalidError,
+            "absolute path '/' is not in base path '" TEST_PATH "/repo'");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("error on path that starts with repo path");
+
+        argListTmp = strLstDup(argList);
+        strLstAddZ(argListTmp, TEST_PATH "/reposub");
+        HRN_CFG_LOAD(cfgCmdRepoLs, argListTmp);
+
+        TEST_ERROR(
+            storageListRender(ioBufferWriteNew(output)), ParamInvalidError,
+            "absolute path '" TEST_PATH "/reposub' is not in base path '" TEST_PATH "/repo'");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("error on //");
+
+        argListTmp = strLstDup(argList);
+        strLstAddZ(argListTmp, "bbb//");
+        HRN_CFG_LOAD(cfgCmdRepoLs, argListTmp);
+
+        TEST_ERROR(
+            storageListRender(ioBufferWriteNew(output)), ParamInvalidError, "path 'bbb//' cannot contain //");
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("subdirectory");
 
-        StringList *argListTmp = strLstDup(argList);
+        argListTmp = strLstDup(argList);
         strLstAddZ(argListTmp, "bbb");
         HRN_CFG_LOAD(cfgCmdRepoLs, argListTmp);
 
@@ -169,6 +213,18 @@ testRun(void)
         TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "subdirectory");
         TEST_RESULT_STR_Z(strNewBuf(output), "ccc\n", "check output");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("subdirectory with /");
+
+        argListTmp = strLstDup(argList);
+        strLstAddZ(argListTmp, "bbb/");
+        HRN_CFG_LOAD(cfgCmdRepoLs, argListTmp);
+
+        output = bufNew(0);
+        cfgOptionSet(cfgOptOutput, cfgSourceParam, VARUINT64(CFGOPTVAL_OUTPUT_TEXT));
+        TEST_RESULT_VOID(storageListRender(ioBufferWriteNew(output)), "subdirectory");
+        TEST_RESULT_STR_Z(strNewBuf(output), "ccc\n", "check output");
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("redirect stdout to a file");
 
@@ -403,9 +459,9 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("put encrypted WAL archive file");
 
-        // Create WAL segment
+        // Create WAL segment. Keep it small since encryption/decryption takes time (esp on 32-bit).
         ioBufferSizeSet(oldBufferSize);
-        Buffer *archiveFileBuffer = bufNew(16 * 1024 * 1024);
+        Buffer *archiveFileBuffer = bufNew(1024);
         memset(bufPtr(archiveFileBuffer), 0, bufSize(archiveFileBuffer));
         bufUsedSet(archiveFileBuffer, bufSize(archiveFileBuffer));
 
@@ -466,7 +522,7 @@ testRun(void)
         hrnCfgArgRawZ(argList, cfgOptRepoPath, TEST_PATH "/repo");
         hrnCfgArgRawStrId(argList, cfgOptRepoCipherType, cipherTypeAes256Cbc);
         hrnCfgArgRawZ(argList, cfgOptCipherPass, "custom2");
-        strLstAdd(argList, STRDEF(STORAGE_PATH_BACKUP "/test/latest/pg_data/backup_label"));
+        strLstAddZ(argList, STORAGE_PATH_BACKUP "/test/latest/pg_data/backup_label");
         HRN_CFG_LOAD(cfgCmdRepoPut, argList);
 
         TEST_RESULT_VOID(storagePutProcess(ioBufferReadNew(backupLabelBuffer)), "put");
@@ -495,7 +551,7 @@ testRun(void)
 
         argList = strLstNew();
         hrnCfgArgRawZ(argList, cfgOptRepoPath, "/");
-        strLstAdd(argList, strNewFmt(TEST_PATH "/repo/%s", strZ(fileName)));
+        strLstAddFmt(argList, TEST_PATH "/repo/%s", strZ(fileName));
         HRN_CFG_LOAD(cfgCmdRepoGet, argList);
 
         writeBuffer = bufNew(0);
@@ -572,7 +628,7 @@ testRun(void)
 
         writeBuffer = bufNew(0);
         TEST_ERROR(
-            storageGetProcess(ioBufferWriteNew(writeBuffer)), OptionInvalidValueError,
+            storageGetProcess(ioBufferWriteNew(writeBuffer)), ParamInvalidError,
             "absolute path '/somewhere/" INFO_ARCHIVE_FILE "' is not in base path '" TEST_PATH "/repo'");
 
         // -------------------------------------------------------------------------------------------------------------------------
@@ -587,7 +643,7 @@ testRun(void)
         writeBuffer = bufNew(0);
         TEST_ERROR(
             storageGetProcess(ioBufferWriteNew(writeBuffer)), OptionInvalidValueError,
-            strZ(strNewFmt("unable to determine cipher passphrase for '%s'", strZ(fileEncCustomName))));
+            zNewFmt("unable to determine cipher passphrase for '%s'", strZ(fileEncCustomName)));
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("get encrypted archive.info - stanza mismatch");
@@ -668,11 +724,9 @@ testRun(void)
         argList = strLstNew();
         hrnCfgArgRawZ(argList, cfgOptRepoPath, TEST_PATH "/repo");
         hrnCfgArgRawStrId(argList, cfgOptRepoCipherType, cipherTypeAes256Cbc);
-        strLstAdd(
-            argList,
-            strNewFmt(
-                "%s/repo/" STORAGE_PATH_ARCHIVE "/test/12-1/000000010000000100000001-aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
-                TEST_PATH));
+        strLstAddFmt(
+            argList, "%s/repo/" STORAGE_PATH_ARCHIVE "/test/12-1/000000010000000100000001-aaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaaa",
+            TEST_PATH);
         HRN_CFG_LOAD(cfgCmdRepoGet, argList);
 
         writeBuffer = bufNew(0);
@@ -724,7 +778,7 @@ testRun(void)
         argList = strLstNew();
         hrnCfgArgRawZ(argList, cfgOptRepoPath, TEST_PATH "/repo");
         hrnCfgArgRawStrId(argList, cfgOptRepoCipherType, cipherTypeAes256Cbc);
-        strLstAdd(argList, STRDEF(STORAGE_PATH_BACKUP "/test/latest/pg_data/backup_label"));
+        strLstAddZ(argList, STORAGE_PATH_BACKUP "/test/latest/pg_data/backup_label");
         HRN_CFG_LOAD(cfgCmdRepoGet, argList);
 
         writeBuffer = bufNew(0);
