@@ -79,18 +79,19 @@ testSuite(CompressType type, const char *decompressCmd)
     Buffer *compressed = NULL;
     Buffer *decompressed = bufNewC(simpleData, strlen(simpleData));
 
-    VariantList *compressParamList = varLstNew();
-    varLstAdd(compressParamList, varNewUInt(1));
+    PackWrite *packWrite = pckWriteNewP();
+    pckWriteI32P(packWrite, 1);
+    pckWriteEndP(packWrite);
 
     // Create default storage object for testing
-    Storage *storageTest = storagePosixNewP(strNew(testPath()), .write = true);
+    Storage *storageTest = storagePosixNewP(TEST_PATH_STR, .write = true);
 
     TEST_TITLE("simple data");
 
     TEST_ASSIGN(
         compressed,
         testCompress(
-            compressFilterVar(strNewFmt("%sCompress", strZ(compressTypeStr(type))), compressParamList), decompressed, 1024,
+            compressFilterPack(compressHelperLocal[type].compressType, pckWriteResult(packWrite)), decompressed, 1024,
             256 * 1024 * 1024),
         "simple data - compress large in/large out buffer");
 
@@ -98,7 +99,7 @@ testSuite(CompressType type, const char *decompressCmd)
     TEST_TITLE("compressed output can be decompressed with command-line tool");
 
     storagePutP(storageNewWriteP(storageTest, STRDEF("test.cmp")), compressed);
-    TEST_SYSTEM_FMT("%s {[path]}/test.cmp > {[path]}/test.out", decompressCmd);
+    HRN_SYSTEM_FMT("%s " TEST_PATH "/test.cmp > " TEST_PATH "/test.out 2> /dev/null", decompressCmd);
     TEST_RESULT_BOOL(bufEq(decompressed, storageGetP(storageNewReadP(storageTest, STRDEF("test.out")))), true, "check output");
 
     TEST_RESULT_BOOL(
@@ -116,8 +117,7 @@ testSuite(CompressType type, const char *decompressCmd)
     TEST_RESULT_BOOL(
         bufEq(
             decompressed,
-            testDecompress(
-                compressFilterVar(strNewFmt("%sDecompress", strZ(compressTypeStr(type))), NULL), compressed, 1024, 1024)),
+            testDecompress(compressFilterPack(compressHelperLocal[type].decompressType, NULL), compressed, 1024, 1024)),
         true, "simple data - decompress large in/large out buffer");
 
     TEST_RESULT_BOOL(
@@ -171,7 +171,7 @@ testSuite(CompressType type, const char *decompressCmd)
 /***********************************************************************************************************************************
 Test Run
 ***********************************************************************************************************************************/
-void
+static void
 testRun(void)
 {
     FUNCTION_HARNESS_VOID();
@@ -196,17 +196,28 @@ testRun(void)
         TEST_ERROR(gzError(Z_VERSION_ERROR), FormatError, "zlib threw error: [-6] incompatible version");
         TEST_ERROR(gzError(999), AssertError, "zlib threw error: [999] unknown error");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("compressLevelDefault(), compressLevelMin(), and compressLevelMax()");
+
+        TEST_RESULT_INT(compressLevelDefault(compressTypeGz), 6, "level default");
+        TEST_RESULT_INT(compressLevelMin(compressTypeGz), -1, "level default");
+        TEST_RESULT_INT(compressLevelMax(compressTypeGz), 9, "level default");
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("gzDecompressToLog() and gzCompressToLog()");
 
+        char buffer[STACK_TRACE_PARAM_MAX];
+
         GzDecompress *decompress = (GzDecompress *)ioFilterDriver(gzDecompressNew());
 
-        TEST_RESULT_STR_Z(gzDecompressToLog(decompress), "{inputSame: false, done: false, availIn: 0}", "format object");
+        TEST_RESULT_VOID(FUNCTION_LOG_OBJECT_FORMAT(decompress, gzDecompressToLog, buffer, sizeof(buffer)), "gzDecompressToLog");
+        TEST_RESULT_Z(buffer, "{inputSame: false, done: false, availIn: 0}", "check log");
 
         decompress->inputSame = true;
         decompress->done = true;
 
-        TEST_RESULT_STR_Z(gzDecompressToLog(decompress), "{inputSame: true, done: true, availIn: 0}", "format object");
+        TEST_RESULT_VOID(FUNCTION_LOG_OBJECT_FORMAT(decompress, gzDecompressToLog, buffer, sizeof(buffer)), "gzDecompressToLog");
+        TEST_RESULT_Z(buffer, "{inputSame: true, done: true, availIn: 0}", "check log");
     }
 
     // *****************************************************************************************************************************
@@ -234,22 +245,32 @@ testRun(void)
         TEST_ERROR(bz2Error(BZ_CONFIG_ERROR), AssertError, "bz2 error: [-9] config error");
         TEST_ERROR(bz2Error(-999), AssertError, "bz2 error: [-999] unknown error");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("compressLevelDefault(), compressLevelMin(), and compressLevelMax()");
+
+        TEST_RESULT_INT(compressLevelDefault(compressTypeBz2), 9, "level default");
+        TEST_RESULT_INT(compressLevelMin(compressTypeBz2), 1, "level default");
+        TEST_RESULT_INT(compressLevelMax(compressTypeBz2), 9, "level default");
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("bz2DecompressToLog() and bz2CompressToLog()");
 
+        char buffer[STACK_TRACE_PARAM_MAX];
+
         Bz2Compress *compress = (Bz2Compress *)ioFilterDriver(bz2CompressNew(1));
 
         compress->stream.avail_in = 999;
 
-        TEST_RESULT_STR_Z(
-            bz2CompressToLog(compress), "{inputSame: false, done: false, flushing: false, avail_in: 999}", "format object");
+        TEST_RESULT_VOID(FUNCTION_LOG_OBJECT_FORMAT(compress, bz2CompressToLog, buffer, sizeof(buffer)), "bz2CompressToLog");
+        TEST_RESULT_Z(buffer, "{inputSame: false, done: false, flushing: false, avail_in: 999}", "check log");
 
         Bz2Decompress *decompress = (Bz2Decompress *)ioFilterDriver(bz2DecompressNew());
 
         decompress->inputSame = true;
         decompress->done = true;
 
-        TEST_RESULT_STR_Z(bz2DecompressToLog(decompress), "{inputSame: true, done: true, avail_in: 0}", "format object");
+        TEST_RESULT_VOID(FUNCTION_LOG_OBJECT_FORMAT(decompress, bz2DecompressToLog, buffer, sizeof(buffer)), "bz2DecompressToLog");
+        TEST_RESULT_Z(buffer, "{inputSame: true, done: true, avail_in: 0}", "check log");
     }
 
     // *****************************************************************************************************************************
@@ -265,16 +286,25 @@ testRun(void)
         TEST_RESULT_UINT(lz4Error(0), 0, "check success");
         TEST_ERROR(lz4Error((size_t)-2), FormatError, "lz4 error: [-2] ERROR_maxBlockSize_invalid");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("compressLevelDefault(), compressLevelMin(), and compressLevelMax()");
+
+        TEST_RESULT_INT(compressLevelDefault(compressTypeLz4), 1, "level default");
+        TEST_RESULT_INT(compressLevelMin(compressTypeLz4), -5, "level default");
+        TEST_RESULT_INT(compressLevelMax(compressTypeLz4), 12, "level default");
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("lz4DecompressToLog() and lz4CompressToLog()");
 
+        char buffer[STACK_TRACE_PARAM_MAX];
+
         Lz4Compress *compress = (Lz4Compress *)ioFilterDriver(lz4CompressNew(7));
 
         compress->inputSame = true;
         compress->flushing = true;
 
-        TEST_RESULT_STR_Z(
-            lz4CompressToLog(compress), "{level: 7, first: true, inputSame: true, flushing: true}", "format object");
+        TEST_RESULT_VOID(FUNCTION_LOG_OBJECT_FORMAT(compress, lz4CompressToLog, buffer, sizeof(buffer)), "lz4CompressToLog");
+        TEST_RESULT_Z(buffer, "{level: 7, first: true, inputSame: true, flushing: true}", "check log");
 
         Lz4Decompress *decompress = (Lz4Decompress *)ioFilterDriver(lz4DecompressNew());
 
@@ -282,9 +312,8 @@ testRun(void)
         decompress->done = true;
         decompress->inputOffset = 999;
 
-        TEST_RESULT_STR_Z(
-            lz4DecompressToLog(decompress), "{inputSame: true, inputOffset: 999, frameDone false, done: true}",
-            "format object");
+        TEST_RESULT_VOID(FUNCTION_LOG_OBJECT_FORMAT(decompress, lz4DecompressToLog, buffer, sizeof(buffer)), "lz4DecompressToLog");
+        TEST_RESULT_Z(buffer, "{inputSame: true, inputOffset: 999, frameDone false, done: true}", "check log");
 #else
         TEST_ERROR(compressTypePresent(compressTypeLz4), OptionInvalidValueError, "pgBackRest not compiled with lz4 support");
 #endif // HAVE_LIBLZ4
@@ -303,17 +332,26 @@ testRun(void)
         TEST_RESULT_UINT(zstError(0), 0, "check success");
         TEST_ERROR(zstError((size_t)-12), FormatError, "zst error: [-12] Version not supported");
 
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("compressLevelDefault(), compressLevelMin(), and compressLevelMax()");
+
+        TEST_RESULT_INT(compressLevelDefault(compressTypeZst), 3, "level default");
+        TEST_RESULT_INT(compressLevelMin(compressTypeZst), -7, "level default");
+        TEST_RESULT_INT(compressLevelMax(compressTypeZst), 22, "level default");
+
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("zstDecompressToLog() and zstCompressToLog()");
 
+        char buffer[STACK_TRACE_PARAM_MAX];
+
         ZstCompress *compress = (ZstCompress *)ioFilterDriver(zstCompressNew(14));
 
         compress->inputSame = true;
         compress->inputOffset = 49;
         compress->flushing = true;
 
-        TEST_RESULT_STR_Z(
-            zstCompressToLog(compress), "{level: 14, inputSame: true, inputOffset: 49, flushing: true}", "format object");
+        TEST_RESULT_VOID(FUNCTION_LOG_OBJECT_FORMAT(compress, zstCompressToLog, buffer, sizeof(buffer)), "zstCompressToLog");
+        TEST_RESULT_Z(buffer, "{level: 14, inputSame: true, inputOffset: 49, flushing: true}", "check log");
 
         ZstDecompress *decompress = (ZstDecompress *)ioFilterDriver(zstDecompressNew());
 
@@ -321,9 +359,8 @@ testRun(void)
         decompress->done = true;
         decompress->inputOffset = 999;
 
-        TEST_RESULT_STR_Z(
-            zstDecompressToLog(decompress), "{inputSame: true, inputOffset: 999, frameDone false, done: true}",
-            "format object");
+        TEST_RESULT_VOID(FUNCTION_LOG_OBJECT_FORMAT(decompress, zstDecompressToLog, buffer, sizeof(buffer)), "zstDecompressToLog");
+        TEST_RESULT_Z(buffer, "{inputSame: true, inputOffset: 999, frameDone false, done: true}", "check log");
 #else
         TEST_ERROR(compressTypePresent(compressTypeZst), OptionInvalidValueError, "pgBackRest not compiled with zst support");
 #endif // HAVE_LIBZST
@@ -335,9 +372,14 @@ testRun(void)
     {
         TEST_TITLE("compressTypeEnum()");
 
-        TEST_RESULT_UINT(compressTypeEnum(STRDEF("none")), compressTypeNone, "none enum");
-        TEST_RESULT_UINT(compressTypeEnum(STRDEF("gz")), compressTypeGz, "gz enum");
-        TEST_ERROR(compressTypeEnum(strNew(BOGUS_STR)), AssertError, "invalid compression type 'BOGUS'");
+        TEST_RESULT_UINT(compressTypeEnum(strIdFromZ("none")), compressTypeNone, "none enum");
+        TEST_RESULT_UINT(compressTypeEnum(strIdFromZ("gz")), compressTypeGz, "gz enum");
+        TEST_ERROR(compressTypeEnum(strIdFromZ(BOGUS_STR)), AssertError, "invalid compression type 'BOGUS'");
+
+        // -------------------------------------------------------------------------------------------------------------------------
+        TEST_TITLE("compressTypeStr()");
+
+        TEST_RESULT_STR_Z(compressTypeStr(compressTypeGz), "gz", "gz str");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("compressTypePresent()");
@@ -352,9 +394,9 @@ testRun(void)
         TEST_RESULT_UINT(compressTypeFromName(STRDEF("file.gz")), compressTypeGz, "type from name");
 
         // -------------------------------------------------------------------------------------------------------------------------
-        TEST_TITLE("compressFilterVar()");
+        TEST_TITLE("compressFilterPack()");
 
-        TEST_RESULT_PTR(compressFilterVar(STRDEF("BOGUS"), 0), NULL, "no filter match");
+        TEST_RESULT_PTR(compressFilterPack(STRID5("bogus", 0x13a9de20), NULL), NULL, "no filter match");
 
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("compressExtStr()");
@@ -365,7 +407,7 @@ testRun(void)
         // -------------------------------------------------------------------------------------------------------------------------
         TEST_TITLE("compressExtCat()");
 
-        String *file = strNew("file");
+        String *file = strCatZ(strNew(), "file");
         TEST_RESULT_VOID(compressExtCat(file, compressTypeGz), "cat gz ext");
         TEST_RESULT_STR_Z(file, "file.gz", "    check gz ext");
 
@@ -375,12 +417,6 @@ testRun(void)
         TEST_ERROR(compressExtStrip(STRDEF("file"), compressTypeGz), FormatError, "'file' must have '.gz' extension");
         TEST_RESULT_STR_Z(compressExtStrip(STRDEF("file"), compressTypeNone), "file", "nothing to strip");
         TEST_RESULT_STR_Z(compressExtStrip(STRDEF("file.gz"), compressTypeGz), "file", "strip gz");
-
-        // -------------------------------------------------------------------------------------------------------------------------
-        TEST_TITLE("compressLevelDefault()");
-
-        TEST_RESULT_INT(compressLevelDefault(compressTypeNone), 0, "none level=0");
-        TEST_RESULT_INT(compressLevelDefault(compressTypeGz), 6, "gz level=6");
     }
 
     FUNCTION_HARNESS_RETURN_VOID();
