@@ -6,12 +6,10 @@ This wrapper runs the C unit tests.
 #include "build.auto.h"
 
 // Enable FUNCTION_TEST*() macros for enhanced debugging
-#ifndef DEBUG_TEST_TRACE
-    #define DEBUG_TEST_TRACE
-#endif
+{[C_TEST_DEBUG_TEST_TRACE]}
 
-// This must be before all includes except build.auto.h
-#ifdef HRN_FEATURE_MEMCONTEXT
+// Enable memory debugging
+#if defined(HRN_FEATURE_MEMCONTEXT) && defined(DEBUG)
     #define DEBUG_MEM
 #endif
 
@@ -32,6 +30,7 @@ The test code is included directly so it can freely interact with the included C
 #include <stdlib.h>
 #include <string.h>
 #include <sys/stat.h>
+#include <unistd.h>
 
 #ifdef HRN_FEATURE_ERROR
     #include "common/error.h"
@@ -152,9 +151,6 @@ main(int argListSize, const char *argList[])
         exit(25);
     }
 
-    // Initialize stack trace for the harness
-    FUNCTION_HARNESS_INIT(argList[0]);
-
     FUNCTION_HARNESS_BEGIN();
         FUNCTION_HARNESS_PARAM(INT, argListSize);
         FUNCTION_HARNESS_PARAM(CHARPY, argList);
@@ -240,7 +236,7 @@ main(int argListSize, const char *argList[])
 
 #ifdef HRN_FEATURE_ERROR
         }
-        CATCH_ANY()
+        CATCH_FATAL()
         {
             // If a test was running then throw a detailed result exception
 #ifdef DEBUG
@@ -290,5 +286,15 @@ main(int argListSize, const char *argList[])
     TRY_END();
 #endif
 
+    // Switch to build path when profiling so profile data gets written to a predictable location
+#if {[C_TEST_PROFILE]}
+    if (chdir("{[C_TEST_PATH_BUILD]}") != 0)
+    {
+        fprintf(stderr, "unable to chdir to '{[C_TEST_PATH_BUILD]}'");
+        fflush(stderr);
+        result = 25;
+    }
+#endif
+
     FUNCTION_HARNESS_RETURN(INT, result);
 }
