@@ -80,11 +80,11 @@ test.pl [options]
    --min-gen            only run required code generation
    --gen-check          check that auto-generated files are correct (used in CI to detect changes)
    --code-count         generate code counts
+   --no-back-trace      don't run backrace on C unit tests (may be slow with valgrind)
    --no-valgrind        don't run valgrind on C unit tests (saves time)
    --no-coverage        don't run coverage on C unit tests (saves time)
    --no-coverage-report run coverage but don't generate coverage report (saves time)
    --no-optimize        don't do compile optimization for C (saves compile time)
-   --backtrace          enable backtrace when available (adds stack trace line numbers -- very slow)
    --profile            generate profile info
    --no-debug           don't generate a debug build
    --scale              scale performance tests
@@ -141,7 +141,7 @@ my $bVersion = false;
 my $bHelp = false;
 my $bQuiet = false;
 my $strPgVersion = 'minimal';
-my $strVm;
+my $strVm = VM_NONE;
 my $bVmBuild = false;
 my $bVmForce = false;
 my $bBuildOnly = false;
@@ -158,8 +158,8 @@ my $bGenOnly = false;
 my $bGenCheck = false;
 my $bMinGen = false;
 my $bCodeCount = false;
-my $bBackTrace = false;
 my $bProfile = false;
+my $bNoBackTrace = false;
 my $bNoValgrind = false;
 my $bNoOptimize = false;
 my $bNoDebug = false;
@@ -175,7 +175,7 @@ GetOptions ('q|quiet' => \$bQuiet,
             'help' => \$bHelp,
             'clean' => \$bClean,
             'clean-only' => \$bCleanOnly,
-            'pgsql-bin=s' => \$strPgSqlBin,
+            'psql-bin=s' => \$strPgSqlBin,
             'test-path=s' => \$strTestPath,
             'make-cmd=s' => \$strMakeCmd,
             'log-level=s' => \$strLogLevel,
@@ -208,8 +208,8 @@ GetOptions ('q|quiet' => \$bQuiet,
             'gen-check' => \$bGenCheck,
             'min-gen' => \$bMinGen,
             'code-count' => \$bCodeCount,
-            'backtrace' => \$bBackTrace,
             'profile' => \$bProfile,
+            'no-back-trace' => \$bNoBackTrace,
             'no-valgrind' => \$bNoValgrind,
             'no-optimize' => \$bNoOptimize,
             'no-debug', => \$bNoDebug,
@@ -269,6 +269,7 @@ eval
     ################################################################################################################################
     if ($bProfile)
     {
+        $bNoBackTrace = true;
         $bNoValgrind = true;
         $bNoCoverage = true;
     }
@@ -298,6 +299,9 @@ eval
         confess "Only one --test can be provided when --run is specified";
     }
 
+    # Check vm
+    vmValid($strVm);
+
     # Set test path if not explicitly set
     if (!defined($strTestPath))
     {
@@ -319,17 +323,6 @@ eval
         }
     }
 
-    # If VM is not defined then set it to all
-    if (!defined($strVm))
-    {
-        $strVm = VM_ALL;
-    }
-    # Else make sure vm is valid
-    elsif ($strVm ne VM_ALL)
-    {
-        vmValid($strVm);
-    }
-
     # Get the base backrest path
     my $strBackRestBase = dirname(dirname(abs_path($0)));
     my $strVagrantPath = "${strBackRestBase}/test/.vagrant";
@@ -393,6 +386,49 @@ eval
         #---------------------------------------------------------------------------------------------------------------------------
         executeTest("make -C ${strBackRestBase}/src -f Makefile.in clean-all");
 
+        # Clean up
+        #---------------------------------------------------------------------------------------------------------------------------
+        my $iTestFail = 0;
+        my $iTestRetry = 0;
+        my $oyProcess = [];
+        my $strCodePath = "${strBackRestBase}/test/result/coverage/raw";
+
+        if (!$bDryRun || $bVmOut)
+        {
+            &log(INFO, "cleanup old data" . ($strVm ne VM_NONE ? " and containers" : ''));
+
+            if ($strVm ne VM_NONE)
+            {
+                containerRemove('test-([0-9]+|build)');
+            }
+
+            for (my $iVmIdx = 0; $iVmIdx < 8; $iVmIdx++)
+            {
+                push(@{$oyProcess}, undef);
+            }
+
+            executeTest(
+                "chmod 700 -R ${strTestPath}/test-* 2>&1 || true && rm -rf ${strTestPath}/temp ${strTestPath}/test-*" .
+                    " ${strTestPath}/data-*");
+            $oStorageTest->pathCreate("${strTestPath}/temp", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
+
+            # Remove old lcov dirs -- do it this way so the dirs stay open in finder/explorer, etc.
+            executeTest("rm -rf ${strBackRestBase}/test/result/coverage/lcov/*");
+
+            # Overwrite the C coverage report so it will load but not show old coverage
+            $oStorageTest->pathCreate(
+                "${strBackRestBase}/test/result/coverage", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
+            $oStorageBackRest->put(
+                "${strBackRestBase}/test/result/coverage/coverage.html", "<center>[ Generating New Report ]</center>");
+
+            # Copy C code for coverage tests
+            if (vmCoverageC($strVm) && !$bDryRun)
+            {
+                executeTest("rm -rf ${strBackRestBase}/test/result/coverage/raw/*");
+                $oStorageTest->pathCreate("${strCodePath}", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
+            }
+        }
+
         # Auto-generate configure files unless --min-gen specified
         #---------------------------------------------------------------------------------------------------------------------------
         if (!$bMinGen)
@@ -491,28 +527,8 @@ eval
             &log(INFO, "    autogenerated configure script: " . (@stryBuilt ? join(', ', @stryBuilt) : 'no changes'));
         }
 
-        # Make a copy of the repo to track which files have been changed
-        #---------------------------------------------------------------------------------------------------------------------------
-        my $strRepoCachePath = "${strTestPath}/repo";
-
-        # Create the repo path -- this should hopefully prevent obvious rsync errors below
-        $oStorageTest->pathCreate($strRepoCachePath, {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
-
-        # Copy the repo
-        executeTest(
-            "git -C ${strBackRestBase} ls-files -c --others --exclude-standard |" .
-                " rsync -rtW --delete --files-from=- --exclude=test/result" .
-                # This option is not supported on MacOS. The eventual plan is to remove the need for it.
-                (trim(`uname`) ne 'Darwin' ? ' --ignore-missing-args' : '') .
-                " ${strBackRestBase}/ ${strRepoCachePath}");
-
-        # Auto-generate code files (if --min-gen specified then do minimum required)
-        #---------------------------------------------------------------------------------------------------------------------------
-        my $strBuildPath = "${strTestPath}/build";
-
-        &log(INFO, (!-e $strBuildPath ? 'clean ' : '') . 'autogenerate code');
-
         # Auto-generate version for root meson.build script
+        #---------------------------------------------------------------------------------------------------------------------------
         my $strMesonBuildOld = ${$oStorageTest->get("${strBackRestBase}/meson.build")};
         my $strMesonBuildNew;
 
@@ -528,24 +544,71 @@ eval
 
         buildPutDiffers($oStorageBackRest, "${strBackRestBase}/meson.build", $strMesonBuildNew);
 
-        # Setup build if it does not exist
-        if (!-e $strBuildPath)
+        # Start build container if vm is not none
+        #---------------------------------------------------------------------------------------------------------------------------
+        if ($strVm ne VM_NONE)
         {
-            executeTest("meson setup -Dwerror=true -Dfatal-errors=true -Dbuildtype=debug ${strBuildPath} ${strBackRestBase}");
+            my $strCCachePath = "${strTestPath}/ccache-0/${strVm}";
+
+            if (!$oStorageTest->pathExists($strCCachePath))
+            {
+                $oStorageTest->pathCreate($strCCachePath, {strMode => '0770', bCreateParent => true});
+            }
+
+            executeTest(
+                "docker run -itd -h test-build --name=test-build" .
+                    " -v ${strBackRestBase}:${strBackRestBase} -v ${strTestPath}:${strTestPath}" .
+                    " -v ${strCCachePath}:/home/${\TEST_USER}/.ccache" . ' ' . containerRepo() . ":${strVm}-test",
+                {bSuppressStdErr => true});
+        }
+
+        # Create path for repo cache
+        #---------------------------------------------------------------------------------------------------------------------------
+        my $strRepoCachePath = "${strTestPath}/repo";
+
+        # Create the repo path -- this should hopefully prevent obvious rsync errors below
+        $oStorageTest->pathCreate($strRepoCachePath, {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
+
+        # Auto-generate code files (if --min-gen specified then do minimum required)
+        #---------------------------------------------------------------------------------------------------------------------------
+        my $strBuildPath = "${strTestPath}/build/${strVm}";
+        my $strBuildNinja = "${strBuildPath}/build.ninja";
+
+        &log(INFO, (!-e $strBuildNinja ? 'clean ' : '') . 'autogenerate code');
+
+        # Setup build if it does not exist
+        my $strGenerateCommand =
+            "ninja -C ${strBuildPath} src/build-code test/src/test-pgbackrest" .
+            ($bMinGen ? '' : " && \\\n${strBuildPath}/src/build-code config ${strBackRestBase}/src") .
+            ($bMinGen ? '' : " && \\\n${strBuildPath}/src/build-code error ${strBackRestBase}/src") .
+            " && \\\n${strBuildPath}/src/build-code postgres ${strBackRestBase}/src ${strRepoCachePath}";
+
+        if (!-e $strBuildNinja)
+        {
+            $strGenerateCommand =
+                "meson setup -Dwerror=true -Dfatal-errors=true -Dbuildtype=debug ${strBuildPath} ${strBackRestBase} && \\\n" .
+                $strGenerateCommand;
         }
 
         # Build code
         executeTest(
-            "ninja -C ${strBuildPath}" . ($bMinGen ? '' : ' src/build-config src/build-error') . ' src/build-postgres' .
-            ($bMinGen ? '' : " && ${strBuildPath}/src/build-config ${strBackRestBase}/src") .
-            ($bMinGen ? '' : " && ${strBuildPath}/src/build-error ${strBackRestBase}/src") .
-            " && cd $strRepoCachePath/src && ${strBuildPath}/src/build-postgres");
+            ($strVm ne VM_NONE ? "docker exec -i -u ${\TEST_USER} test-build bash -l -c ' \\\n" : '') .
+            $strGenerateCommand . ($strVm ne VM_NONE ? "'" : ''));
 
         if ($bGenOnly)
         {
             exit 0;
         }
 
+        # Make a copy of the repo to track which files have been changed
+        #---------------------------------------------------------------------------------------------------------------------------
+        executeTest(
+            "git -C ${strBackRestBase} ls-files -c --others --exclude-standard |" .
+                " rsync -rLtW --delete --files-from=- --exclude=test/result" .
+                # This option is not supported on MacOS. The eventual plan is to remove the need for it.
+                (trim(`uname`) ne 'Darwin' ? ' --ignore-missing-args' : '') .
+                " ${strBackRestBase}/ ${strRepoCachePath}");
+
         # Generate code counts
         #---------------------------------------------------------------------------------------------------------------------------
         if ($bCodeCount)
@@ -556,49 +619,6 @@ eval
             exit 0;
         }
 
-        # Clean up
-        #---------------------------------------------------------------------------------------------------------------------------
-        my $iTestFail = 0;
-        my $iTestRetry = 0;
-        my $oyProcess = [];
-        my $strCodePath = "${strBackRestBase}/test/result/coverage/raw";
-
-        if (!$bDryRun || $bVmOut)
-        {
-            &log(INFO, "cleanup old data" . ($strVm ne VM_NONE ? " and containers" : ''));
-
-            if ($strVm ne VM_NONE)
-            {
-                containerRemove('test-([0-9]+|build)');
-            }
-
-            for (my $iVmIdx = 0; $iVmIdx < 8; $iVmIdx++)
-            {
-                push(@{$oyProcess}, undef);
-            }
-
-            executeTest(
-                "chmod 700 -R ${strTestPath}/test-* 2>&1 || true && rm -rf ${strTestPath}/temp ${strTestPath}/test-*" .
-                    " ${strTestPath}/data-*");
-            $oStorageTest->pathCreate("${strTestPath}/temp", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
-
-            # Remove old lcov dirs -- do it this way so the dirs stay open in finder/explorer, etc.
-            executeTest("rm -rf ${strBackRestBase}/test/result/coverage/lcov/*");
-
-            # Overwrite the C coverage report so it will load but not show old coverage
-            $oStorageTest->pathCreate(
-                "${strBackRestBase}/test/result/coverage", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
-            $oStorageBackRest->put(
-                "${strBackRestBase}/test/result/coverage/coverage.html", "<center>[ Generating New Report ]</center>");
-
-            # Copy C code for coverage tests
-            if (vmCoverageC($strVm) && !$bDryRun)
-            {
-                executeTest("rm -rf ${strBackRestBase}/test/result/coverage/raw/*");
-                $oStorageTest->pathCreate("${strCodePath}", {strMode => '0770', bIgnoreExists => true, bCreateParent => true});
-            }
-        }
-
         # Determine which tests to run
         #---------------------------------------------------------------------------------------------------------------------------
         my $oyTestRun;
@@ -657,7 +677,6 @@ eval
         {
             my $oVm = vmGet();
             my $lTimestampLast;
-            my $strBinPath = "${strTestPath}/bin";
             my $rhBinBuild = {};
 
             # Build the binary
@@ -679,47 +698,45 @@ eval
 
                 foreach my $strBuildVM (@stryBuildVm)
                 {
-                    my $strBuildPath = "${strBinPath}/${strBuildVM}";
-
                     if ($strBuildVM eq VM_NONE)
                     {
-                        &log(INFO, "    " . (!-e $strBuildPath ? 'clean ' : '') . "bin build for ${strBuildVM} (${strBuildPath})");
+                        my $strBuildPath = "${strTestPath}/build/${strBuildVM}";
+                        my $strBuildNinja = "${strBuildPath}/build.ninja";
+
+                        &log(INFO, "    " . (!-e $strBuildNinja ? 'clean ' : '') . "bin build for ${strBuildVM} (${strBuildPath})");
 
                         # Setup build if it does not exist
-                        if (!-e $strBuildPath)
+                        my $strBuildCommand = "ninja -C ${strBuildPath} src/pgbackrest";
+
+                        if (!-e $strBuildNinja)
                         {
-                            executeTest(
+                            $strBuildCommand =
                                 "meson setup -Dwerror=true -Dfatal-errors=true -Dbuildtype=debug ${strBuildPath}" .
-                                    " ${strBackRestBase}");
+                                    " ${strBackRestBase} && \\\n" .
+                                $strBuildCommand;
                         }
 
                         # Build code
-                        executeTest("ninja -C ${strBuildPath}");
+                        executeTest($strBuildCommand);
                     }
                     else
                     {
+                        my $strBinPath = "${strTestPath}/bin";
+                        my $strBuildPath = "${strBinPath}/${strBuildVM}";
+
                         &log(INFO, "    bin build for ${strBuildVM} (${strBuildPath})");
 
                         my $bRebuild = false;
                         $rhBinBuild->{$strBuildVM} = false;
 
                         # Build configure/compile options and see if they have changed from the previous build
-                        my $strCFlags =
-                            (vmWithBackTrace($strBuildVM) && $bBackTrace ? ' -DWITH_BACKTRACE' : '') .
-                            ($bDebugTestTrace ? ' -DDEBUG_TEST_TRACE' : '');
-                        my $strLdFlags = vmWithBackTrace($strBuildVM) && $bBackTrace ? '-lbacktrace' : '';
+                        my $strCFlags = ($bDebugTestTrace ? ' -DDEBUG_TEST_TRACE' : '');
                         my $strConfigOptions = (vmDebugIntegration($strBuildVM) ? ' --enable-test' : '');
-                        my $strBuildFlags = "CFLAGS_EXTRA=${strCFlags}\nLDFLAGS_EXTRA=${strLdFlags}\nCONFIGURE=${strConfigOptions}";
+                        my $strBuildFlags = "CFLAGS_EXTRA=${strCFlags}\nCONFIGURE=${strConfigOptions}";
                         my $strBuildFlagFile = "${strBinPath}/${strBuildVM}/build.flags";
 
                         my $bBuildOptionsDiffer = buildPutDiffers($oStorageBackRest, $strBuildFlagFile, $strBuildFlags);
 
-                        executeTest(
-                            "docker run -itd -h test-build --name=test-build" .
-                                " -v ${strBackRestBase}:${strBackRestBase} -v ${strTestPath}:${strTestPath} " .
-                                containerRepo() . ":${strBuildVM}-test",
-                            {bSuppressStdErr => true});
-
                         if ($bBuildOptionsDiffer ||
                             !-e "${strBuildPath}/Makefile" ||
                             stat("${strBackRestBase}/src/Makefile.in")->mtime > stat("${strBuildPath}/Makefile")->mtime ||
@@ -741,15 +758,19 @@ eval
                         executeTest(
                             'docker exec -i -u ' . TEST_USER . ' test-build ' .
                             "${strMakeCmd} -s -j ${iBuildMax}" . ($bLogDetail ? '' : ' --silent') .
-                                " --directory ${strBuildPath} CFLAGS_EXTRA='${strCFlags}'" .
-                                ($strLdFlags ne '' ? " LDFLAGS_EXTRA='${strLdFlags}'" : ''),
+                                " --directory ${strBuildPath} CFLAGS_EXTRA='${strCFlags}'",
                             {bShowOutputAsync => $bLogDetail});
-
-                        executeTest("docker rm -f test-build");
                     }
                 }
             }
 
+            # Shut down the build vm
+            #-----------------------------------------------------------------------------------------------------------------------
+            if ($strVm ne VM_NONE)
+            {
+                executeTest("docker rm -f test-build");
+            }
+
             # Build the package
             #-----------------------------------------------------------------------------------------------------------------------
             if ($bBuildPackage && $strVm ne VM_NONE)
@@ -784,7 +805,7 @@ eval
                             "bash -c 'git clone https://salsa.debian.org/postgresql/pgbackrest.git /root/package-src 2>&1'");
 
                         executeTest(
-                            "rsync -r --exclude=.vagrant --exclude=.git --exclude=test/result ${strBackRestBase}/" .
+                            "rsync -rL --exclude=.vagrant --exclude=.git --exclude=test/result ${strBackRestBase}/" .
                                 " ${strBuildPath}/");
                         executeTest(
                             ($strVm ne VM_NONE ? "docker exec -i test-build " : '') .
@@ -1037,8 +1058,8 @@ eval
                     my $oJob = new pgBackRestTest::Common::JobTest(
                         $oStorageTest, $strBackRestBase, $strTestPath, $$oyTestRun[$iTestIdx], $bDryRun, $bVmOut, $iVmIdx, $iVmMax,
                         $strMakeCmd, $iTestIdx, $iTestMax, $strLogLevel, $strLogLevelTest, $strLogLevelTestFile, !$bNoLogTimestamp,
-                        $bShowOutputAsync, $bNoCleanup, $iRetry, !$bNoValgrind, !$bNoCoverage, $bCoverageSummary, !$bNoOptimize,
-                        $bBackTrace, $bProfile, $iScale, $strTimeZone, !$bNoDebug, $bDebugTestTrace,
+                        $bShowOutputAsync, $bNoCleanup, $iRetry, !$bNoBackTrace, !$bNoValgrind, !$bNoCoverage, $bCoverageSummary,
+                        !$bNoOptimize, $bProfile, $iScale, $strTimeZone, !$bNoDebug, $bDebugTestTrace,
                         $iBuildMax / $iVmMax < 1 ? 1 : int($iBuildMax / $iVmMax));
                     $iTestIdx++;
 
@@ -1097,7 +1118,7 @@ eval
         $strBackRestBase,                                           # Base backrest directory
         $strTestPath,                                               # Path where the tests will run
         dirname($strTestPath) . "/bin/${strVm}/" . PROJECT_EXE,     # Path to the pgbackrest binary
-        dirname($strTestPath) . "/bin/" . VM_NONE . '/src/' . PROJECT_EXE,  # Path to the pgbackrest storage helper
+        dirname($strTestPath) . "/build/" . VM_NONE . '/src/' . PROJECT_EXE,  # Path to the pgbackrest storage helper
         $strPgVersion ne 'minimal' ? $strPgSqlBin: undef,           # Pg bin path
         $strPgVersion ne 'minimal' ? $strPgVersion: undef,          # Pg version
         $stryModule[0], $stryModuleTest[0], \@iyModuleTestRun,      # Module info
